#ifndef _FRAMEGRABBERGENERIC_H
#define _FRAMEGRABBERGENERIC_H

#include "../camera_generic.h"
//#include <ipl98/cpp/std_image.h>
//#include "../../ipl98/ipl98_cplusplus_containers.h"

namespace ipl{ // use namespace in C++

/** NB: Beta version, some of the functionality may be changed and
	parts of it may not work properly!!!
    CFrameGrabberGeneric is an abstract base class from which all
	frame grabber classes are derived. A frame grabber
    class is the only class needed for grabbing an image. More advanced
    features should be found in the inherited classes. This class is not
    complete and a lot of changes in near future must be expected.
	Last updated 28/3/2000. 

	@version 0.2, by kirstein@mip.sdu.dk
	@author Ren Dencker Eriksen & Brian Kirstein Ramsgaard */

class CFrameGrabberGeneric{
	protected: // attributes
        /** List of cameras connected to the framegrabber, in this implementation
			a hard limit of 10 is defined. */
        CCameraGeneric* m_CameraList[10];
		/** to check if the framegrabber device is open, set by Open() and Close()
			methods, use IsDeviceOpen() to get the value. */
		bool m_DeviceOpen;
		/** Internal flag to check if the m_Width and m_Heigh dimesnions has been
			set, set to false in constructor. */
		bool m_DimensionsAvailable;
		/** The maximum width of image to be grabbed, set by Initialize() method */
		unsigned int m_Width;
		/** The maximum height of image to be grabbed, set by Initialize() method */
		unsigned int m_Height;
	public: // methods
		/** Default constructor, must be called by the inherited class. Inits the attribute
			m_CameraList[10] to NULL pointers. Sets the two attributes m_DeviceOpen and 
			m_DimensionsAvailable to false. */
        CFrameGrabberGeneric();
		/** Default destructor, must be called by the inherited class. Calls the method Close(). */
        ~CFrameGrabberGeneric();
		/** Sets the  m_DeviceOpen attribute to true, owerwrite in your derived class if needed, but
			always call this method from your derived Open(). */
		virtual bool Open();
		/** Sets the  m_DeviceOpen attribute to false, owerwrite in your derived class if needed, but
			always call this method from your derived Open(). */
		virtual bool Close();
		/** cheks if the device has been succesfully opened with Open() method. */
		bool IsDeviceOpen();
    	/** Acquire image from camera that Camera is referring to.
			@return false if grabbing failed */
		virtual bool Acquire(CStdImage& Image, CCameraGeneric& Camera)=0;
        /** Add a camera to a specific port on the frame grabber */
        bool AddCamera(unsigned short portNr, CCameraGeneric& Camera);
        /** Remove a camera from the frame grabber */
        bool RemoveCamera(CCameraGeneric& Camera);
		/** Get the maximum width of image. Note: the dimensions are only valid if they
			are set by the inherited class. Read documentation for the actual class to
			see what method sets these values. Normally it is done by an Initialize(...)
			method or the Open() method.
			@return Width in pixels or 0 if not available. */
		virtual unsigned int GetWidth(){ return m_Width;}
		/** Get the maximum height of image. Note: the dimensions are only valid if they
			are set by the inherited class. Read documentation for the actual class to
			see what method sets these values. Normally it is done by an Initialize(...)
			method or the Open() method.
			@return Height in pixels or 0 if not available. */
		virtual unsigned int GetHeight(){ return m_Height;}
    protected: // methods
        bool GetPortNumber(unsigned short& PortNr, CCameraGeneric& Camera);
};

} // end namespace ipl

#endif //_FRAMEGRABBERGENERIC_H