#include "com.h"
#include <iostream>

using std::cerr;
using std:: endl;

namespace ipl{ // use namespace if C++

CCom::CCom()
{
	m_PortOpen = false;
}


CCom:: ~CCom()
{
	if(m_PortOpen)
		Close();
}



bool CCom::Open(string portName)
{
	m_Handle = CreateFile(portName.c_str(),GENERIC_READ | GENERIC_WRITE,FILE_SHARE_READ,NULL,OPEN_EXISTING,0,NULL);
	if(m_Handle == INVALID_HANDLE_VALUE)
	{
		cerr << "Error in CCom::Read: Unable to create handle to " << portName << endl;
		return false;
	}
	m_PortName = portName;
	m_PortOpen = true;
	return true;
}



bool CCom::Close()
{
	if(!CloseHandle(m_Handle))
	{
		cerr << "Error in CCom::Read: Unable to close handle to " << m_PortName << endl; 
		return false;
	}
	m_PortOpen = false;
	return true;
}



bool CCom::IsPortOpen()
{
	return m_PortOpen;
}



bool CCom::Read(string& inString)
{
	if(m_Handle == INVALID_HANDLE_VALUE)
	{
		cerr << "Error in CCom::Read: Could not read. Invalid handle to " << m_PortName << endl;
		return false;
	}
	const unsigned long bytesToRead = 80;
	unsigned long bytesRead = 80; // Set to 80 to enter loop. ReadFile() sets it to zero before doing anything
	inString.erase();
	while(bytesRead == bytesToRead)
	{
		char* tmpStr = new char[bytesToRead];
		memset(tmpStr,0,bytesToRead);
		ReadFile(m_Handle,tmpStr,bytesToRead,&bytesRead,NULL);
		inString.append(tmpStr);
		delete tmpStr;
	}
//	cout << "Bytes read " << bytesRead << endl;
//	cout << "inString = " << inString << endl;
	return true;
}



bool CCom::Read(string& inString, unsigned int nBytes)
{
	if(m_Handle == INVALID_HANDLE_VALUE)
	{
		cerr << "Error in CCom::Read: Could not read. Invalid handle to " << m_PortName << endl;
		return false;
	}

	char* tmpStr = new char[nBytes];
	memset(tmpStr,0,nBytes);
	unsigned long bytesRead;
	ReadFile(m_Handle,tmpStr,nBytes,&bytesRead,NULL);
	inString.erase();
	inString.append(tmpStr);
	delete tmpStr;
	return true;
}



bool CCom:: Write(string outString)
{
	if(m_Handle == INVALID_HANDLE_VALUE)
	{
		cerr << "Error in CCom::Read: Could not write. Invalid handle to " << m_PortName << endl;
		return false;
	}
	unsigned long bytesToWrite = outString.length();
//	cout << "bytesToWrite=" << bytesToWrite << "  string " << outString << endl;
	unsigned long bytesWritten = 0; 
	WriteFile(m_Handle,outString.c_str(),bytesToWrite,&bytesWritten,NULL);
	return true;
}

} // end namespace ipl
