/* Header file for class CCom											*/
/* Class used for communication with the serial communication device	*/
/* Author: Peter Hauge													*/
/* Ver. 0.1															*/
/* Date: 7.12.1998														*/

#ifndef __COM_H
#define __COM_H

#include <string>
#include <wtypes.h>

//using namespace std;
using std::string;

namespace ipl{ // use namespace if C++

/** Class used for communication with the serial communication device.
	Updated 7/12/1998.
	@version 0.1,  by hauge@trivision.dk
	@author Peter Hauge */	
class CCom
{
private:
	HANDLE m_Handle;
	string m_PortName;
	bool m_PortOpen;
	
public:
	CCom();
	~CCom();
	/** Opens the port specified by "portName".
		@param portName The com port to be used, use "COM" followed by the port number,
			for instance "COM1" or "COM2".
		@return False, if opening failed, errors are written to the stream "cerr". */
	bool Open(string portName);
	/** Closes the connection.
		@return False, if fails. */
	bool Close();
	/** True, if the port is open */
	bool IsPortOpen();
	/** Reads a character from the serial port.
		@param inString Character returned in this string.
		@return False, if the internal handle to port is invalid. */
	bool Read(string& inString);
	/** Reads "nBytes" characters from the serial port.
		@param inString Characters returned in this string.
		@return False, if the internal handle to port is invalid. */
	bool Read(string& inString, unsigned int nBytes);
	/** Sends all characters contained in "outString" to the serial port.
		@param outString Characters to be send to serial port.
		@return False, if the internal handle to port is invalid. */
	bool Write(string outString);
};

} // end namespace ipl

#endif //__COM_H
