#include "camera_firewire_cmu.h"
#include <fstream>
#include <process.h> // necessary in order to use _beginthread and _endthread
#include <winbase.h>
#include <strstream>


using std::ofstream;
using std::istringstream;
using std::strstream;
using std::endl;
	
/*****************************
* ------ Camera General ----*
*****************************/
	
	
vector<CCameraFirewireCMU::CAMERA_STRUCT*> CCameraFirewireCMU::m_ConnectedCams;
vector<CCameraFirewireCMU*> CCameraFirewireCMU::m_CamObjects;
unsigned int CCameraFirewireCMU::m_TotalCams = 0;
bool CCameraFirewireCMU::m_QueryCameras = false;
const double CCameraFirewireCMU::m_Version=0.40;
const unsigned int CCameraFirewireCMU::CAM_DELAY_SLEEP=50;

CCameraFirewireCMU::CCameraFirewireCMU(){
	m_SettingsInitialized=false;
	m_Selected = false;
	m_Initialized = false;
	m_AcquireStarted = false;
	m_ExtendedAcquireStarted = false;
	memset(m_ModesAvailable, false, sizeof(m_ModesAvailable));
	memset(m_FormatsAvailable, false, sizeof(m_FormatsAvailable));
	m_CamObjects.push_back(this);
}

CCameraFirewireCMU::CCameraFirewireCMU(const CCameraFirewireCMU& Source)
{
	// copy constructor
	m_CamObjects.push_back(this);
	*this=Source; // use assignment operator
}

CCameraFirewireCMU::~CCameraFirewireCMU()
{
	Close();
	std::vector<CCameraFirewireCMU*>::iterator it;
	bool ObjectDeleted=false;
	for(it=m_CamObjects.begin();it<m_CamObjects.end(); it++)
	{
		if (*it==this)
		{
			m_CamObjects.erase(it);
			ObjectDeleted=true;
		}
	}
	if ((ObjectDeleted==false) && (m_CamObjects.begin()!=m_CamObjects.end()))
	{
		strstream ost;
		ost << "CCameraFirewireCMU::~CCameraFirewireCMU() Internal destructor "
			"error - check code" << "\n";
		//CError::ShowMessage(IPL_ERROR, ost.str().c_str());
	}
	if (m_CamObjects.begin()==m_CamObjects.end())
	{
		for(int i=0; i<m_ConnectedCams.size();i++)
		{
			delete m_ConnectedCams[i]->m_phCamera;
			delete m_ConnectedCams[i];
		}
		m_ConnectedCams.clear();
		m_QueryCameras=false;
	}
}

double CCameraFirewireCMU::GetVersion()
{
	return m_Version;
}

unsigned int CCameraFirewireCMU::QueryCameras()
{
	

	// first close all existing cameras
	for(int i=0; i<m_CamObjects.size(); i++){
		m_CamObjects[i]->Close();
	}
	C1394Camera CamClass;
	CamClass.CheckLink(); //Refresh Camera List
	m_TotalCams = CamClass.GetNumberCameras(); 
	
	for(int  i = 0; i<m_ConnectedCams.size();i++)
	{
		delete m_ConnectedCams[i]->m_phCamera;
		delete m_ConnectedCams[i];
	}
	m_ConnectedCams.resize(m_TotalCams);
	//collect information for each camera
	for(int node = 0; node < m_TotalCams; node++)
	{
		CAMERA_STRUCT* Cam = new CAMERA_STRUCT;
		C1394Camera* currentCam = new C1394Camera;
		strstream ost;
		currentCam->CheckLink();
		if(currentCam->SelectCamera(node) != CAM_SUCCESS)
		{
			ost << "CCameraFirewireCMU::QueryCameras() failed querying node "
				<< node << "."<< endl <<"\n";
			//CError::ShowMessage(IPL_ERROR, ost.str().c_str());
		}
		memset(currentCam->m_nameVendor, 0 , 256);
		memset(currentCam->m_nameModel, 0 , 256);
		
		currentCam->InitCamera();
		currentCam->InquireControlRegisters();
		
		Cam->m_phCamera = currentCam;
		Cam->m_ModelName = currentCam->m_nameModel;
		Cam->m_VendorName = currentCam->m_nameVendor;
		Cam->m_SerialNumber = currentCam->m_UniqueID.LowPart;
		m_ConnectedCams[node] = Cam;
		
	}
	m_QueryCameras = true;
	return m_TotalCams;
}

bool CCameraFirewireCMU::SelectCamera(int node)
{			
	if (!m_QueryCameras)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::SelectCamera() Must call QueryCameras() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	
	if(node<GetTotalCameras() && node >= 0)
	{
		// if the camera was running, it must be stopped before switching
		if (ImageCaptureStarted()==true)
			StopImageCapture();
		else if (ImageAcquisitionExtendedStarted()==true)
			StopImageAcquisitionExtended();
		m_phCamera = m_ConnectedCams[node]->m_phCamera;
		m_Selected = true;
		m_Initialized = false;
		return true;
	}
	return false;
}

bool CCameraFirewireCMU::SelectCameraName(string name)
{
	if (!m_QueryCameras)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::SelectCameraName() Must call QueryCameras() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	for(int i=0; i<GetTotalCameras(); i++){
		if(name==m_ConnectedCams[i]->m_ModelName)
		{
			// if the camera was running, it must be stopped before switching
			if (ImageCaptureStarted()==true)
				StopImageCapture();
			else if (ImageAcquisitionExtendedStarted()==true)
				StopImageAcquisitionExtended();
			m_phCamera = m_ConnectedCams[i]->m_phCamera;
			m_Selected = true;
			m_Initialized = false;
			return true;
		}
	}
	return false;
}

bool CCameraFirewireCMU::SelectCameraSerial(unsigned long int serial)
{		
	if(!m_QueryCameras)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::SelectCameraSerial() Must call QueryCameras() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	for(int i=0; i<GetTotalCameras();i++){
		if(serial==m_ConnectedCams[i]->m_SerialNumber)
		{
			// if the camera was running, it must be stopped before switching
			if (ImageCaptureStarted()==true)
				StopImageCapture();
			else if (ImageAcquisitionExtendedStarted()==true)
				StopImageAcquisitionExtended();
			m_phCamera = m_ConnectedCams[i]->m_phCamera;
			m_Selected = true;
			m_Initialized = false;
			return true;
		}
	}
	return false;
}	

	
bool CCameraFirewireCMU::Initialize()
{
	if(!m_Selected)
		return false;
	m_phCamera->StatusControlRegisters();
	m_phCamera->InquireControlRegisters();
	ReadFormatsModes();
	ReadAutoExposure();
	ReadBrightness();
	ReadFocus();
	ReadGain();
	ReadGamma();
	ReadHue();
	ReadIris();
	ReadSaturation();
	ReadSharpness();
	ReadShutter();
	ReadWhiteBalance();
	ReadZoom();
	// The following activates features (if available) and sets them to manual
	// added by Ren Dencker Eriksen, edr@mip.sdu.dk
	m_Initialized = true;
	if (AutoExposureAvailable())
	{
		SetAutoExposureAuto(false);
		SetAutoExposureOn(true);
	}
	if (BrightnessAvailable())
	{
		SetBrightnessAuto(false);
		SetBrightnessOn(true);
	}
	if (FocusAvailable())
	{
		//SetFocusAuto(false);
		SetFocusOn(true);
	}
	if (GainAvailable())
	{
		SetGainAuto(false);
		SetGainOn(true);
	}
	if (GammaAvailable())
	{
		//SetGammaAuto(false);
		SetGammaOn(true);
	}
	if (HueAvailable())
	{
		//SetHueAuto(false);
		SetHueOn(true);
	}
	if (IrisAvailable())
	{
		SetIrisAuto(false);
		SetIrisOn(true);
	}
	if (SaturationAvailable())
	{
		SetSaturationAuto(false);
		SetSaturationOn(true);
	}
	if (SharpnessAvailable())
	{
		SetSharpnessAuto(false);
		SetSharpnessOn(true);
	}
	if (ShutterAvailable())
	{
		SetShutterAuto(false);
		SetShutterOn(true);
	}
	if (WhiteBalanceAvailable())
	{
		SetWhiteBalanceAuto(false);
		SetWhiteBalanceOn(true);
	}
	if (ZoomAvailable())
	{
		SetZoomOn(true);
	}
	// since the CMU driver does not support reading the format, mode
	// and frame rate at this time, we simly select a random available setup
	unsigned int Format=0, Mode=0;
	while ((FormatAvailable(Format)==false) && (Format<=7))
		Format++;
	if (Format>7)
		return false;
	while ((FormatAndModeAvailable(Format, Mode)==false) && (Mode<=7))
		Mode++;
	if (Mode>7)
		return false;
	if (SetFormatMode(Format,Mode)==false)
		return false;
	if (Format!=7)
	{
		vector<double> FrameRates;
		GetFrameRatesAvailable(Format,Mode,FrameRates);
		SetFrameRate(FrameRates.back());
	}
	if (ImageCaptureStarted()==false)
	{
		if (StartImageCapture()==true)
		{
			m_Initialized = true;
			m_SettingsInitialized=true;
			return true;
		}
		else
			return false;
	}
	else
	{
		m_Initialized = true;
		m_SettingsInitialized=true;
		return true;
	}
}
	
bool CCameraFirewireCMU::Close()
{

	if (ImageCaptureStarted()==true){
		StopImageCapture();
	}else if (ImageAcquisitionExtendedStarted()==true){
		StopImageAcquisitionExtended();		
	}

	m_Initialized = false;
	return true;
}

unsigned int CCameraFirewireCMU::GetTotalCameras()
{
	if (!m_QueryCameras)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetTotalCameras() Must call QueryCameras() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_TotalCams;
}

int CCameraFirewireCMU::GetHeight()
{
	if(!m_Initialized){
		strstream ost;
		ost << "CCameraFirewireCMU::GetHeight() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_phCamera->m_height;
}

int CCameraFirewireCMU::GetWidth()
{
	if(!m_Initialized){
		strstream ost;
		ost << "CCameraFirewireCMU::GetWidth() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_phCamera->m_width;
}


/*Get camera name*/
string CCameraFirewireCMU::GetCameraName() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetCameraName() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return "N/A";
	}
	
	strstream ost;
	ost << m_phCamera->m_nameModel;
	return ost.str();		
}
	
/*Get camera vendor*/
string CCameraFirewireCMU::GetCameraVendor() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetCameraVendor() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return "N/A";
	}
	strstream ost;
	ost << m_phCamera->m_nameVendor;
	return ost.str();		
}

/*Get camera serial numer*/
unsigned long int CCameraFirewireCMU::GetSerialNumber() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSerialNumber() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_phCamera->m_UniqueID.LowPart; //Only the first 32 bit of serial
}	


bool CCameraFirewireCMU::GetAllCameraInfo(vector<string>& CamInfo)
{
	if (!m_QueryCameras)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetAllCameraInfo() Must call QueryAllCameras() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	CamInfo.resize(GetTotalCameras());
	for(int i=0; i<GetTotalCameras(); i++)
	{
		CAMERA_STRUCT* Cam=m_ConnectedCams[i];
		strstream ost;
		ost << Cam->m_VendorName << " : " << Cam->m_ModelName << " : " << Cam->m_SerialNumber;
		
		CamInfo[i]=ost.str();
	}
	return true;
}

//bool CCameraFirewireCMU::GetAllCameraInfo(vector<string>& CamInfo)
//{
//	if (!m_QueryCameras)
//	{
//		strstream ost;
//		ost << "CCameraFirewireCMU::GetAllCameraInfo() Must call QueryAllCameras() first." 
//			<< "\n";
//		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
//		return false;
//	}
//	CamInfo.resize(GetTotalCameras());
//	for(int i=0; i<GetTotalCameras(); i++)
//	{
//		CAMERA_STRUCT Cam=m_ConnectedCams[i];
//		strstream ost;
//		ost << Cam.m_VendorName << " : " << Cam.m_ModelName << " : " << Cam.m_SerialNumber;
//		
//		CamInfo[i]=ost.str();
//	}
//	return true;
//}

bool CCameraFirewireCMU::SplitCameraInfo(const char* CamInfo, string& Vendor, string& Model, 
							unsigned long int& SerialNr)
{
	string str(CamInfo);
	short Pos=str.find_first_of(':');
	if (Pos==string::npos)
		return false;
	Vendor=str.substr(0,Pos-1);
	str.erase(0,Pos+2);
	Pos=str.find_first_of(':');
	if (Pos==string::npos)
		return false;
	Model=str.substr(0,Pos-1);
	str.erase(0,Pos+2);
	//istringstream is(str);
	//is >> SerialNr;
	return true;
}


//************ LOAD & SAVE *******************

bool CCameraFirewireCMU::Save(const char* pPathAndFileName) const
{
	if (pPathAndFileName==NULL)
		return false;
	ofstream os(pPathAndFileName);
	if (!os)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::Save() Failed opening file: " << pPathAndFileName << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	else
	{/* write to file */
		try
		{
			//os << *this;
		}
		catch(...)
		{
			return false;
		}
	}
	return true;
}

strstream& operator<<(strstream& os, const CCameraFirewireCMU& Cam)
{
	if (Cam.m_Initialized==false)
	{
		strstream ost;
		ost << "operator<<(strstream&, const CCameraFirewireCMU&) Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		throw(ost.str());
	}
	os << "# Firewire camera setup written by CCameraFirewireCMU class" << endl;
	os << "#\n# CCameraFirewireCMU class version" << endl;
	os << "CamFirewireCMUVersion: " << Cam.GetVersion() << endl << endl;
	os << "# camera identification" << endl;
	os << "VendorName:   " << Cam.GetCameraVendor() << endl;
	os << "ModelName:    " << Cam.GetCameraName() << endl;
	os << "SerialNumber: " << Cam.GetSerialNumber() << endl << endl;
	
	os << "# camera pixel setup, resolution, and framerate" << endl;
	os << "Format: " << Cam.GetFormat() << endl;
	os << "Mode: " << Cam.GetMode() << endl;

	/* not implemented
	if (Cam.GetFormat()==7)
	{
		CPoint2D<UINT16> UL, LR;
		Cam.GetPartialScan(UL,LR);
		os << "# Format 7 resolution is " << LR.GetX()-UL.GetX() << "*" << LR.GetY()-UL.GetY() << endl;
		os << "# note: following three lines only present when format 7 is active" << endl;
		os << "PartialScan:" << endl
			<< "   Upperleft:  " << UL << endl 
			<< "   LowerRight: " << LR << endl;
		os << "# the following line commented out because framerate not available in format 7" << endl;
		os << "# FrameRate:    15" << endl << endl;
	}
	else
	*/
	{
		os << "FrameRate:    " << Cam.GetFrameRate() << endl << endl;
	}
	
	os << "# Firewire camera settings " << endl;
	os << "# note: if a feature is not present, it's value is set to -1" << endl << endl;
	//AE
	if (Cam.AutoExposureAvailable())
	{
		os << "# AutoExposure interval: [" << Cam.GetAutoExposureMin() << "," << Cam.GetAutoExposureMax() << "]" << endl;
		os << "AutoExposureValue: " << Cam.GetAutoExposure() << endl;
		//		os << "AutoExposureAuto: " << Cam.GetAutoExposureAuto() << endl; // edr: removed, look at this later
	}
	else
		os << "AutoExposureValue: -1" << endl;
	//BR
	if (Cam.BrightnessAvailable())
	{
		os << "# Brightness interval: [" << Cam.GetBrightnessMin() << "," 
			<< Cam.GetBrightnessMax() << "]" << endl;
		os << "BrightnessValue: " << Cam.GetBrightness() << endl;
		//		os << "BrightnessAuto: " << Cam.GetBrightnessAuto() << endl; // edr: removed, look at this later
	}
	else
		os << "BrightnessValue: -1" << endl;
	//FO
	if (Cam.FocusAvailable())
	{
		os << "# Focus interval: [" << Cam.GetFocusMin() << "," << Cam.GetFocusMax() << "]" << endl;
		os << "FocusValue: " << Cam.GetFocus() << endl;
	}
	else
		os << "FocusValue: -1" << endl;
	//GN
	if (Cam.GainAvailable())
	{
		os << "# Gain interval: [" << Cam.GetGainMin() << "," << Cam.GetGainMax() << "]" << endl;
		os << "GainValue: " << Cam.GetGain() << endl;
		//		os << "GainAuto: " << Cam.GetGainAuto() << endl; // edr: removed, look at this later
	}
	else
		os << "GainValue: -1" << endl;
	//GM
	if (Cam.GammaAvailable())
	{
		os << "# Gamma interval: [" << Cam.GetGammaMin() << "," << Cam.GetGammaMax() << "]" << endl;
		os << "GammaValue: " << Cam.GetGamma() << endl;
	}
	else
		os << "GammaValue: -1" << endl;
	//HU
	if (Cam.HueAvailable())
	{
		os << "# Hue interval: [" << Cam.GetHueMin() << "," << Cam.GetHueMax() << "]" << endl;
		os << "HueValue: " << Cam.GetHue() << endl;
	}
	else
		os << "HueValue: -1" << endl;
	//IR
	if (Cam.IrisAvailable())
	{
		os << "# Iris interval: [" << Cam.GetIrisMin() << "," << Cam.GetIrisMax() << "]" << endl;
		os << "IrisValue: " << Cam.GetIris() << endl;
		//		os << "IrisAuto: " << Cam.GetIrisAuto() << endl; // edr: removed, look at this later
	}
	else
		os << "IrisValue: -1" << endl;
	//ST
	if (Cam.SaturationAvailable())
	{
		os << "# Saturation interval: [" << Cam.GetSaturationMin() << "," 
			<< Cam.GetSaturationMax() << "]" << endl;
		os << "SaturationValue: " << Cam.GetSaturation() << endl;
		//		os << "SaturationAuto: " << Cam.GetSaturationAuto() << endl; // edr: removed, look at this later
	}
	else
		os << "SaturationValue: -1" << endl;
	//SA
	if (Cam.SharpnessAvailable())
	{
		os << "# Sharpness interval: [" << Cam.GetSharpnessMin() << "," 
			<< Cam.GetSharpnessMax() << "]" << endl;
		os << "SharpnessValue: " << Cam.GetSharpness() << endl;
		//		os << "SharpnessAuto: " << Cam.GetSharpnessAuto() << endl; // edr: removed, look at this later
	}
	else
		os << "SharpnessValue: -1" << endl;
	//SU
	if (Cam.ShutterAvailable())
	{
		os << "# Shutter interval: [" << Cam.GetShutterMin() << "," << Cam.GetShutterMax() << "]" << endl;
		os << "ShutterValue: " << Cam.GetShutter() << endl;
		//		os << "ShutterAuto: " << Cam.GetShutterAuto() << endl; // edr: removed, look at this later
	}
	else
		os << "ShutterValue: -1" << endl;
	//WB
	if (Cam.WhiteBalanceAvailable())
	{
		os << "# WhiteBalance interval: [" << Cam.GetWhiteBalanceMin() << "," << Cam.GetWhiteBalanceMax() << "]" << endl;
		os << "WhiteBalanceValueUB: " << Cam.GetWhiteBalance().first << endl;
		os << "WhiteBalanceValueVR: " << Cam.GetWhiteBalance().second << endl;
		//		os << "WhiteBalanceAuto: " << Cam.GetWhiteBalanceAuto() << endl; // edr: removed, look at this later
	}
	else
		os << "WhiteBalanceValue: -1" << endl;
	//ZO
	if (Cam.ZoomAvailable())
	{
		os << "# Zoom interval: [" << Cam.GetZoomMin() << "," << Cam.GetZoomMax() << "]" << endl;
		os << "ZoomValue: " << Cam.GetZoom() << endl;
	}
	else
		os << "ZoomValue: -1" << endl;	
	
	return os;
}

//LOAD
bool CCameraFirewireCMU::Load(const char* pPathAndFileName, bool Start)
{
	if ((pPathAndFileName==NULL) || (string(pPathAndFileName)==string("")))
	{
		strstream ost;
		ost << "CCameraFirewireCMU::Load() File name is empty" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	ifstream is(pPathAndFileName);
	if (!is)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::Load() Failed opening file: " << pPathAndFileName << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	else
	{
		/* read from file */
		try
		{
			//is >> *this;
			if (m_QueryCameras==false)
				QueryCameras();
			Sleep(CAM_DELAY_SLEEP);
			if ((Start==true) && (SetWithCurrentValues()==false))
			{
				strstream ost;
				ost << "CCameraFirewireCMU::Load() Failed starting camera " << "\n";
				throw(ost.str());
			}
			else
			{
				if (ImageCaptureStarted()==true)
					StopImageCapture();
				else if (ImageAcquisitionExtendedStarted()==true)
					return StopImageAcquisitionExtended();
			}

		}
		catch(string str)
		{
			strstream ost;
			ost << "CCameraFirewireCMU::Load() Failed with error: " << str.c_str() << "\n";
			//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
			return false;
		}
	}
	return true;
}

bool CCameraFirewireCMU::GetCameraVendorNameSerial(const char* pPathAndFileName, double& Version,
						string& Vendor, string& Name, unsigned long int& Serial) const
{
	if ((pPathAndFileName==NULL) || (string(pPathAndFileName)==string("")))
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetCameraVendorNameSerial() File name is empty" 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	ifstream is(pPathAndFileName);
	if (!is)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetCameraVendorNameSerial() Failed opening file: " 
			<< pPathAndFileName << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	else
	{
		return GetCameraVendorNameSerial(is, Version, Vendor, Name, Serial);
	}
}

bool CCameraFirewireCMU::GetFrameRateIndex(double FR, unsigned int& FrameRateIndex) const
{
	for(int i=0; i<7; i++)
	{
		if (FR==FrameRates[i])
		{
			FrameRateIndex=i;
			return true;
		}
	}
	strstream ost;
	ost << "CCameraFirewireCMU::GetFrameRateIndex() Frame rate: " << FR << " does not exist"
		<< "\n";
	//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
	return false;
}

bool CCameraFirewireCMU::SetWithCurrentValues() throw (string){
	if (m_QueryCameras==false)
		QueryCameras();
	if (SelectCameraSerial(m_SerialNumber)==false)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::SetWithCurrentValues() Failed selecting camera." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	// we copy the current internal settings because we have to call Initialize()
	// afterwards we set these settings for the selected camera
	unsigned int Format=m_Format, Mode=m_Mode;
	unsigned int FrameRate=m_FrameRate;
	double AutoExposureValue=m_AutoExposureValue,
		BrightnessValue=m_BrightnessValue,
		FocusValue=m_FocusValue,
		GainValue=m_GainValue,
		GammaValue=m_GammaValue,
		HueValue=m_HueValue,
		IrisValue=m_IrisValue,
		SaturationValue=m_SaturationValue,
		SharpnessValue=m_SharpnessValue,
		ShutterValue=m_ShutterValue,
		WhiteBalanceUB=m_WhiteBalanceUB,
		WhiteBalanceVR=m_WhiteBalanceVR,
		ZoomValue=m_ZoomValue;
	//CPoint2D<UINT16> UL=m_UL, LR=m_LR;

	if (Initialize()==false)
		return false;
	float ActualFrameRate;
	if (Format==7) // in case of format 7 we cannot index into FrameRates[] since it may not be allocated!
		ActualFrameRate=0; // just a dummy value
	else
		ActualFrameRate=FrameRates[FrameRate];
	if (SetFormatModeFrameRate(Format,Mode,ActualFrameRate)==false)
		return false;
	
	/*if (Format==7)
	{
		if (SetPartialScan(UL,LR)==false)
		{
			string str("CCameraFirewireCMU::SetWithCurrenValues() Failed setting shutter");
			throw(str);
			return false;
		}
	}
	*/
	
	// in the following, only set a feature if it's value in this class is not -1
	if ((AutoExposureAvailable()==true) && (SetAutoExposure(AutoExposureValue)==-1))
	{
		string str("CCameraFirewireCMU::SetWithCurrenValues() Failed setting auto exposure");
		throw(str);
		return false;
	}
	if ((ShutterAvailable()==true) && (SetShutter(ShutterValue)==-1))
	{
		string str("CCameraFirewireCMU::SetWithCurrenValues() Failed setting shutter");
		throw(str);
		return false;
	}
	if ((GainAvailable()==true) && (SetGain(GainValue)==-1))
	{
		string str("CCameraFirewireCMU::SetWithCurrenValues() Failed setting gain");
		throw(str);
		return false;
	}
	if ((WhiteBalanceAvailable()==true) && 
		((SetWhiteBalance(WhiteBalanceUB,WhiteBalanceVR)==pair<double,double>(-1,-1))))
	{
		string str("CCameraFirewireCMU::SetWithCurrenValues() Failed setting Whitebalance");
		throw(str);
		return false;
	}
	if ((BrightnessAvailable()==true) && (SetBrightness(BrightnessValue)==-1))
	{
		string str("CCameraFirewireCMU::SetWithCurrenValues() Failed setting Brightness");
		throw(str);
		return false;
	}
	if ((GammaAvailable()==true) && (SetGamma(GammaValue)==-1))
	{
		string str("CCameraFirewireCMU::SetWithCurrenValues() Failed setting Gamma");
		throw(str);
		return false;
	}
	if ((SaturationAvailable()==true) && (SetSaturation(SaturationValue)==-1))
	{
		string str("CCameraFirewireCMU::SetWithCurrenValues() Failed setting Saturation");
		throw(str);
		return false;
	}
	if ((SharpnessAvailable()==true) && (SetSharpness(SharpnessValue)==-1))
	{
		string str("CCameraFirewireCMU::SetWithCurrenValues() Failed setting Sharpness");
		throw(str);
		return false;
	}
	if (ImageCaptureStarted()==false)
		return StartImageCapture();
////	else if (ImageAcquisitionExtendedStarted()==false)
////		return StartImageAcquisitionExtended(m_ThreadData.Buffers); // start with same number of buffers
//	else
		return true;
}

		

bool CCameraFirewireCMU::GetCurrentSettings(strstream& os) const
{
	if (m_Initialized==false)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetCurrentSettings() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		os << "n/a";
		return false;
	}
	else
	{
		string FormatModeName;
		unsigned int Mode=GetMode();
		unsigned int Format=GetFormat();
		GetFormatModeName(FormatModeName, Format, Mode);
		os << "Vendor: " << GetCameraVendor() << " Camera: " << GetCameraName() << " " << GetSerialNumber() << endl
			<< "Format: " << GetFormat() << " Mode: " << GetMode() << "  -  " << FormatModeName << endl;
		
		
		/*if (GetFormat()==7)
		{
			CPoint2D<UINT16> UL, LR;
			GetPartialScan(UL,LR);
			os << "    PartialScan resolution " << LR-UL << ":"
				<< "   Upperleft:  " << UL << "  LowerRight: " << LR << endl;
		}
		else*/
		{
			os << "  FrameRate:    " << GetFrameRate();
		}
		if (AutoExposureAvailable()==true)
			os << "  Auto exposure: " << GetAutoExposure();
		if (ShutterAvailable()==true)
			os << "  Shutter: " << GetShutter();
		if (GainAvailable()==true)
			os << " Gain: " << GetGain();
		os << endl;
		if (WhiteBalanceAvailable()==true)
		{
			os << "  UB: " << GetWhiteBalance().first;
			os << " VR: " << GetWhiteBalance().second;
		}
		if (BrightnessAvailable()==true)
			os << " Brightness: " << GetBrightness();
		if (GammaAvailable()==true)
			os << " Gamma: " << GetGamma();
		os << endl;
		if (SaturationAvailable()==true)
			os << "  Saturation: " << GetSaturation();
		if (SharpnessAvailable()==true)
			os << " Sharpness: " << GetSharpness();
		os << endl;
		return true;
	}
}

/* *************************** *
* - Format/Mode/Frame Rate -- *
* *************************** */

// Various tables and arrays containing information on formats.

const unsigned int CCameraFirewireCMU::BitsPerPixelTable[3][8] = 
{
	{24,16,12,16,24,8,16,24}, 
	{16,24, 8,16,24,8,16,16},
	{16,24, 8,16,24,8,16,16}
};

const string CCameraFirewireCMU::sImageSize[3][8] = 
{
	{"160x120","320x240","640x480","640x480","640x480","640x480","640x480","N/A"},
	{"800x600","800x600","800x600","800x600","1024x768","1024x768","800x600","1024x768"},
	{"1280x960","1280x960","1280x960","1600x1200","1600x1200","1600x1200","1280x960","1600x1200"}
};

const unsigned int CCameraFirewireCMU::ImageSize[3][8][2] = 
{
	{{160,120},{320,240},{640,480},{640,480},{640,480},{640,480},{640,480},{0,0}},
	{{800,600},{800,600},{800,600},{800,600},{1024,768},{1024,768},{800,600},{1024,768}},
	{{1280,960},{1280,960},{1280,960},{1600,1200},{1600,1200},{1600,1200},{1280,960},{1600,1200}}
};

const string CCameraFirewireCMU::sColorFormat[3][8] =
{
	{"YUV(4:4:4) [24-bit]","YUV(4:2:2) [16-bit]","YUV(4:1:1) [12-bit]","YUV(4:2:2)[16-bit]", 
		"RGB [24-bit]","Mono [8-bit]","Mono [16-bit]","N/A"},
	{"YUV(4:2:2) [16-bit]","RGB [24-bit]","Mono [8-bit]","YUV(4:2:2) [16-bit]", 
	"RGB [24-bit]","Mono [8-bit]","Mono [16-bit]","Mono [16-bit]"},
	{"YUV(4:2:2) [16-bit]","RGB [24-bit]","Mono [8-bit]","YUV(4:2:2) [16-bit]", 
	"RGB [24-bit]","Mono [8-bit]","Mono [16-bit]","Mono [16-bit]"}
};

const string CCameraFirewireCMU::sFrameRates[6] = {"1.875 fps","3.75 fps","7.5 fps","15 fps","30 fps","60 fps"};
const double CCameraFirewireCMU::FrameRates[6] = {1.875, 3.75, 7.5, 15, 30, 60};

// methods begin

bool CCameraFirewireCMU::GetAllFormatsAndModes(strstream& os) const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetAllFormatsAndModes() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	for (int format=0; format<3; format++)
	{
		for (int mode=0; mode<8; mode++)
			for (int rate=0; rate<6; rate++)
				if (m_phCamera->m_videoFlags[format][mode][rate])
				{						
					os << "Format "<< format << ", Mode " << mode << ", Frame Rate " << rate << " : " << 
						sImageSize[format][mode] << " " << sColorFormat[format][mode] << " " << sFrameRates[rate] << endl;
				}
	}
	m_phCamera->m_controlSize.Status();
	if(m_PartialScanAvailable)
	{
		for(int pmode=0; pmode < 8; pmode++)
			if (m_PartialScanModes[pmode])
				os << "Format 7, Mode " << pmode << endl;
	}
	os << endl << "All color formats with more than 8 bit are converted to 24 bit." << endl;
	return true;
}


bool CCameraFirewireCMU::SetFormatModeFrameRate(unsigned int Format, unsigned int Mode, double FrameRate)
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetFormatModeFrameRate() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	bool CaptureStarted=false, AcquisitionExtendedStarted=false;
	if (ImageCaptureStarted()==true)
	{
		StopImageCapture(); 
		CaptureStarted=true;
	}
	else if (ImageAcquisitionExtendedStarted()==true)
	{
		StopImageAcquisitionExtended();
		AcquisitionExtendedStarted=true;
	}
	if(Format<8 && Mode<8){
		
		
		if(Format < 7)
		{
			unsigned int RateIdx;
			if(!m_ModesAvailable[Format][Mode])
			{
				//mode not available
				ost << "CCameraFirewireCMU::SetFormatModeFrameRate() Invalid combination of format and mode." << "\n";
				//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
				return false;
			}
			if(GetFrameRateIndex(FrameRate, RateIdx) == false)
			{ 
				//invalid frame rate not available
				ost << "CCameraFirewireCMU::SetFormatModeFrameRate() Invalid Frame rate." << "\n";
				//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
				return false;
			}
			if(!m_phCamera->m_videoFlags[Format][Mode][RateIdx])
			{
				ost << "CCameraFirewireCMU::SetFormatModeFrameRate() Frame rate not available." << "\n";
				//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
				return false;
			}
			// set format/mode/frame rate
			if(m_phCamera->SetVideoFormat(Format) == CAM_SUCCESS){
				if(m_phCamera->SetVideoMode(Mode) == CAM_SUCCESS)
					if(m_phCamera->SetVideoFrameRate(RateIdx) == CAM_SUCCESS){
						m_Format = Format;
						m_Mode = Mode;
						m_FrameRate = RateIdx;
						m_BitsPerPixel = GetBitsPerPixel(Format, Mode);
						m_Width = ImageSize[m_Format][m_Mode][0];
						m_Height = ImageSize[m_Format][m_Mode][1];
						if (CaptureStarted==true)
							StartImageCapture();
						else if (AcquisitionExtendedStarted==true)
							StartImageAcquisitionExtended();
						return true;
					}
			}
			ost << "CCameraFirewireCMU::SetFormatModeFrameRate() Error setting format mode or frame rate." << "\n";
			//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
			return false;
		}
		//partial scan
		else if(m_PartialScanAvailable)
		{
			if(m_PartialScanModes[Mode])
			{
				if(m_phCamera->SetVideoFormat(Format) == CAM_SUCCESS)
				{
					if(m_phCamera->SetVideoMode(Mode) == CAM_SUCCESS)
					{
						m_Format = Format;	
						m_Mode = Mode;
						m_FrameRate = -1;
						// edr: Note, we cannot set the m_BitsPerPixel at this 
						// point, we will wait til we have setup the partial scan
//						if(Format7ColorCoding[m_phCamera->m_controlSize.m_colorCode] == 8) 
//							m_BitsPerPixel = 8;
//						else
//							m_BitsPerPixel = 24;
//						m_Width = m_phCamera->m_width;
//						m_Height = m_phCamera->m_height;
						C1394CameraControlSize &control = m_phCamera->m_controlSize;
						control.Inquire();
						
						// not implemented
						//m_UL.Set(0,0);
						//m_LR.Set(control.m_maxH,control.m_maxV);
						//SetPartialScan(m_UL, m_LR);
						
						
						if (CaptureStarted==true)
							StartImageCapture();
						else if (AcquisitionExtendedStarted==true)
							StartImageAcquisitionExtended();
						return true;
					}
				}
				ost << "CCameraFirewireCMU::SetFormatModeFrameRate() Error setting partial format or mode ." << "\n";
				//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
				return false;
			}
			ost << "CCameraFirewireCMU::SetFormatModeFrameRate() Partial scan mode not available." << "\n";
			//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
			return false;
		}
		else{
			ost << "CCameraFirewireCMU::SetFormatModeFrameRate() Partial scan not available." << "\n";
			//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
			return false;
		}
	}
	ost << "CCameraFirewireCMU::SetFormatModeFrameRate() Invalid format or mode value." << "\n";
	//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
	return false;
}

bool CCameraFirewireCMU::SetFormatMode(unsigned int Format, unsigned int Mode)
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetFormatMode() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	bool CaptureStarted=false, AcquisitionExtendedStarted=false;
	if (ImageCaptureStarted()==true)
	{
		StopImageCapture();
		CaptureStarted=true;
	}
	else if (ImageAcquisitionExtendedStarted()==true)
	{
		StopImageAcquisitionExtended();
		AcquisitionExtendedStarted=true;
	}
	if(Format<8 && Mode<8){
		if(Format < 7)
		{
			if(!m_ModesAvailable[Format][Mode])
			{
				//mode not available
				ost << "CCameraFirewireCMU::SetFormatMode() Invalid combination of format and mode." << "\n";
				//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
				return false;
			}
			// set format and mode
			if(m_phCamera->SetVideoFormat(Format) == CAM_SUCCESS){
				if(m_phCamera->SetVideoMode(Mode) == CAM_SUCCESS)
				{
					m_Format = Format;
					m_Mode = Mode;
					m_FrameRate = m_phCamera->GetVideoFrameRate();
					m_BitsPerPixel = GetBitsPerPixel(Format, Mode);
					m_Width = ImageSize[m_Format][m_Mode][0];
					m_Height = ImageSize[m_Format][m_Mode][1];
					if (CaptureStarted==true)
						StartImageCapture();
					else if (AcquisitionExtendedStarted==true)
						StartImageAcquisitionExtended();
					return true;
				}
			}
			ost << "CCameraFirewireCMU::SetFormatMode() Error setting format mode or frame rate." << "\n";
			//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
			return false;
		}
		//partial scan
		else if(m_PartialScanAvailable)
		{
			if(m_PartialScanModes[Mode])
			{
				if(m_phCamera->SetVideoFormat(Format) == CAM_SUCCESS)
				{
					if(m_phCamera->SetVideoMode(Mode) == CAM_SUCCESS)
					{
						m_Format = Format;	
						m_Mode = Mode;
						m_FrameRate = -1;
//						if(Format7ColorCoding[m_phCamera->m_controlSize.m_colorCode] == 8) 
//							m_BitsPerPixel = 8;
//						else
//							m_BitsPerPixel = 24;
//						m_Width = m_phCamera->m_width;
//						m_Height = m_phCamera->m_height;
						C1394CameraControlSize &control = m_phCamera->m_controlSize;
						control.Inquire();
						// not implemented
						//m_UL.Set(0,0);
						//m_LR.Set(control.m_maxH,control.m_maxV);
						//SetPartialScan(m_UL, m_LR);
						if (CaptureStarted==true)
							StartImageCapture();
						else if (AcquisitionExtendedStarted==true)
							StartImageAcquisitionExtended();
						return true;
					}
				}
				ost << "CCameraFirewireCMU::SetFormatMode() Error setting partial format or mode ." << "\n";
				//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
				return false;
			}
			ost << "CCameraFirewireCMU::SetFormatMode() Partial scan mode not available." << "\n";
			//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
			return false;
		}
		else{
			ost << "CCameraFirewireCMU::SetFormatMode() Partial scan not available." << "\n";
			//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
			return false;
		}
	}
	ost << "CCameraFirewireCMU::SetFormatMode() Invalid format or mode value." << "\n";
	//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
	return false;
}

bool CCameraFirewireCMU::FormatAndModeAvailable(unsigned int Format, unsigned int Mode) const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::FormatAndModeAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(Format>=0 && Format<3 && Mode >= 0 && Mode < 8)	
		return m_ModesAvailable[Format][Mode];
	else if(Format == 7)
		return m_PartialScanModes[Mode];
	return false;
}

bool CCameraFirewireCMU::FormatAvailable(unsigned int Format) const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::FormatAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(Format == 7)
		return m_PartialScanAvailable;
	else
		return ((Format<3) && m_FormatsAvailable[Format]);
}

bool CCameraFirewireCMU::FrameRateAvailable(double Rate) const
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::FrameRateAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(m_Format==7){
		ost << "CCameraFirewireCMU::FrameRateAvailable() Frame rate note available for format 7." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	int RateIdx;
	for(int i=0; i < 6; i++)
		if(Rate == FrameRates[i]){
			RateIdx = i;
			break;
		}
		return m_phCamera->m_videoFlags[m_Format][m_Mode][RateIdx];
}

unsigned int CCameraFirewireCMU::GetFormat() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetFormat() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_Format;
}

int CCameraFirewireCMU::GetMode() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetMode() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_Mode;
}


double CCameraFirewireCMU::GetFrameRate() const
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::GetFrameRate() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if(m_Format==7){
		ost << "CCameraFirewireCMU::GetFrameRate() Frame rate note available for format 7." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return FrameRates[m_FrameRate];	
}

string CCameraFirewireCMU::GetFormatName() const
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::GetFormatName() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return "Information not available.";
	}
	ost << "Format " << m_Format;
	return ost.str();	
}

string CCameraFirewireCMU::GetFormatName(unsigned int Format) const
{
	strstream ost;
	ost << "Format " << Format;
	return ost.str();		
}


bool CCameraFirewireCMU::GetFrameRatesAvailable(unsigned int Format, unsigned int Mode, vector<double>& FrameRates) const
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::GetFrameRatesAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(Format==7){
		ost << "CCameraFirewireCMU::GetFrameRatesAvailable() Frame rates note available for format 7." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	FrameRates.clear();
	if(Format>=0 && Format<=3 && Mode >= 0 && Mode <= 8){
		for (int rate=0; rate<6; rate++)
			if (m_phCamera->m_videoFlags[Format][Mode][rate])
			{
				double Val;
				Val=CCameraFirewireCMU::FrameRates[rate];
				FrameRates.push_back(CCameraFirewireCMU::FrameRates[rate]);
			}
			return true;
	}
	return false;
}

/*
bool CCameraFirewireCMU::GetFrameRatesAvailable(strstream& os) {
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::GetFrameRatesAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (m_Format==7)
	{
		ost << "CCameraFirewireCMU::GetFrameRatesAvailable() Frame rates not available for format 7." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	for (int rate=0; rate<6; rate++)
		if (m_phCamera->m_videoFlags[m_Format][m_Mode][rate])
			os << sFrameRates[rate] << " ";
		return true;
}
*/

string CCameraFirewireCMU::GetModeName() const{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetModeName() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return "Information not available.";
	}
	string Str;
	if(m_Format>=0 && m_Format<=2 && m_Mode >= 0 && m_Mode <= 7){
		Str.append(sImageSize[m_Format][m_Mode] + " " + sColorFormat[m_Format][m_Mode]);
	}
	else if (m_Format==7)
	{
		strstream ost;
		ost << "Mode " << m_Mode;
		Str=ost.str();
	}
//	if (m_Format==7)
//		ost << "Mode " << m_Mode;
//	else
//		ost << "Mode " << m_Mode << " : " << sImageSize[m_Format][m_Mode] << " - " << sColorFormat[m_Format][m_Mode] << " - " << sFrameRates[m_FrameRate];
	return Str;
}

string CCameraFirewireCMU::GetModeName(unsigned int Mode) const
{
	strstream ost;
	if (m_Format==7)
		ost << "Mode " << Mode;	
	else
		ost << "Mode " << Mode << " : " << sImageSize[m_Format][Mode] << " - " << sColorFormat[m_Format][Mode];
	return ost.str();
}

bool CCameraFirewireCMU::ModeAvailable(unsigned int Mode) const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::ModeAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(m_Format==7)
		return m_PartialScanModes[Mode];
	if(Mode >= 0 && Mode <= 8)
		return m_ModesAvailable[m_Format][Mode];
	else 
		return false;
}

bool CCameraFirewireCMU::SetFrameRate(double Rate)
{
	if (!m_Initialized)
	{
		printf("problem - need init() first \n");
		//strstream ost;
		//cout << "CCameraFirewireCMU::SetFrameRate() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}		
	int RateNo=-1;
	strstream ost;
	bool status = false;
	for(int i=0; i < 6; i++)
		if(Rate == FrameRates[i]){
			RateNo = i;
			
			}
		if(RateNo==-1)
		{
			ost << "CCameraFirewireCMU::SetFrameRate() Wrong Rate given." << "\n";
			//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
			return false;
		}
		
		switch(m_phCamera->SetVideoFrameRate(RateNo))
		{
		case CAM_SUCCESS:
			m_FrameRate = RateNo;
			status = true;
			break;
		case CAM_ERROR_NOT_INITIALIZED:
			ost << "CCameraFirewireCMU::SetFrameRate() Must call Initialize() first." << "\n";
			//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
			break;
		case CAM_ERROR_BUSY:
			ost << "CCameraFirewireCMU::SetFrameRate() Error, stop acquiescence of images to change frame rate." << "\n";
			//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
			break;	
		case CAM_ERROR:
			ost << "CCameraFirewireCMU::SetFrameRate() Error in device driver." << "\n";
			//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
			break;		
		}
		return status;
}

/* static methods */	

bool CCameraFirewireCMU::GetFormatModeName(string& Str, unsigned int Format, unsigned int Mode) const
{
	if(Format>=0 && Format<=2 && Mode >= 0 && Mode <= 7){
		Str.append(sImageSize[Format][Mode] + " " + sColorFormat[Format][Mode]);
		return true;
	}
	else if (Format==7)
	{
		strstream ost;
		ost << "Mode " << Mode;
		Str=ost.str();
		return true;
	}
	return false;
}


unsigned int CCameraFirewireCMU::GetBitsPerPixel(unsigned int Format, unsigned int Mode) const
{
	unsigned int bpp, bpp2;
	bpp2 = BitsPerPixelTable[Format][Mode];
	if( bpp2> 8)
		bpp = 24;
	else
		bpp = 8;
	return bpp;
}


bool CCameraFirewireCMU::ReadFormatsModes()
{
	ReadAvailableFormatsModes();
	m_Format = m_phCamera->GetVideoFormat();
	m_Mode = m_phCamera->GetVideoMode();
	m_FrameRate = m_phCamera->GetVideoFrameRate();
	m_Width = ImageSize[m_Format][m_Mode][0];
	m_Height = ImageSize[m_Format][m_Mode][1];
	return true;
}

bool CCameraFirewireCMU::ReadAvailableFormatsModes()
{
	//m_AcquireStarted = false;
	m_ExtendedAcquireStarted = false;
	memset(m_ModesAvailable, false, sizeof(m_ModesAvailable));
	memset(m_FormatsAvailable, false, sizeof(m_FormatsAvailable));
	
	for (int format=0; format<3; format++)
	{
		for (int mode=0; mode<8; mode++)
		{
			for (int rate=0; rate<6; rate++)
			{
				if (m_phCamera->m_videoFlags[format][mode][rate]){
					m_FormatsAvailable[format] = true;
					m_ModesAvailable[format][mode] = true;		
				}
			}
		}
	}

	C1394CameraControlSize &control = m_phCamera->m_controlSize;
	if(control.Supported())
	{
		control.Status();
		m_PartialScanAvailable = true;
		for (int pmode=0; pmode<=7; pmode++)
			m_PartialScanModes[pmode] = control.ModeSupported(pmode);
	}
	else
		m_PartialScanAvailable  = false;
	return true;
}

/* *************************** *
* ------- Partial Scan ------ *
* *************************** */


const string CCameraFirewireCMU::sFormat7ColorCoding[7] = {"Mono8 [8-bit]", "4:1:1 YUV8 [8-bit]", 
"4:2:2 YUV8 [8-bit]", "4:4:4 YUV8 [8-bit]", "RGB8 [8-bit]", "Mono16 [16-bit]", "RGB16 [16-bit]"};


// from the IIDC_Spec_v1_30pdf
// Mono8 [0] Y only. Y=8bits, non compressed ID=0
// 4:1:1 YUV8 [1] 4:1:1, Y=U=V= 8bits, non compressed ID=1
// 4:2:2 YUV8 [2] 4:2:2, Y=U=V=8bits, non compressed ID=2
// 4:4:4 YUV8 [3] 4:4:4, Y=U=V=8bits, non compressed ID=3
// RGB8 [4] R=G=B=8bits, non compressed ID=4
// Mono16 [5] Y only, Y=16bits, non compressed ID=5
// RGB16 [6] R=G=B=16bits, non compressed ID=6
// edr: changed to support what can be created by the CImage class
const unsigned int CCameraFirewireCMU::Format7ColorCoding[7] = {8, 24, 24, 24, 24, 8, 24};
//const unsigned int CCameraFirewireCMU::Format7ColorCoding[7] = {8, 8, 8, 8, 8, 16, 16};


bool CCameraFirewireCMU::PartialScanAvailable() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::PartialScanAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_PartialScanAvailable;	
}

/*
bool CCameraFirewireCMU::GetPartialScan(CPoint2D<UINT16>& UpperLeft, CPoint2D<UINT16>& LowerRight) const 
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::GetPartialScan() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (m_Format!=7)
	{
		ost << "CCameraFirewireCMU::GetPartialScan() Camera not set to partial scan." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	C1394CameraControlSize &control = m_phCamera->m_controlSize;
	if(control.Status() != CAM_SUCCESS)
	{
		ost << "CCameraFirewireCMU::GetPartialScan() Error accessing size information." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	UpperLeft.Set(control.m_left, control.m_top);
	LowerRight.Set(control.m_left + control.m_width, control.m_top + control.m_height);
	return true;
}


bool CCameraFirewireCMU::SetPartialScan(const CPoint2D<UINT16>& UpperLeft, const CPoint2D<UINT16>& LowerRight)
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetPartialScan() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (m_Format!=7)
	{
		ost << "CCameraFirewireCMU::SetPartialScan() Camera not set to partial scan mode." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	C1394CameraControlSize &control = m_phCamera->m_controlSize;
	control.Inquire();
	if(UpperLeft.GetX() > LowerRight.GetX() || LowerRight.GetX() > control.m_maxH
		|| UpperLeft.GetY() > LowerRight.GetY() || LowerRight.GetY() > control.m_maxV)
	{
		ost << "CCameraFirewireCMU::SetPartialScan() Area of interest invalid." << "\n";	
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	m_UL=UpperLeft;
	m_LR=LowerRight;
	unsigned int DisplacementX, DisplacementY;
	DisplacementX = UpperLeft.GetX() % control.m_unitH;
	DisplacementY = UpperLeft.GetY() % control.m_unitV;
	control.SetPosition(UpperLeft.GetX() - DisplacementX, UpperLeft.GetY() - DisplacementY);
	if (DisplacementX!=0 || DisplacementY!=0)
	{
		ost << "CCameraFirewireCMU::SetPartialScan() UpperLeft position aligned to cell grid unit" << "\n";
		//CError::ShowMessage(IPL_WARNING,ost.str().c_str());
	}
	DisplacementX = LowerRight.GetX() % control.m_unitH;
	DisplacementY = LowerRight.GetY() % control.m_unitV;
	if(DisplacementX != 0)
		DisplacementX = control.m_unitH - DisplacementX;
	if(DisplacementY != 0)
		DisplacementY = control.m_unitV - DisplacementY;
	m_Width = LowerRight.GetX() + DisplacementX - control.m_left;
	m_Height = LowerRight.GetY() + DisplacementY - control.m_top;
	control.SetSize(m_Width, m_Height);
	// Now we have the colorCode available
	if(Format7ColorCoding[m_phCamera->m_controlSize.m_colorCode] == 8) 
		m_BitsPerPixel = 8;
	else
		m_BitsPerPixel = 24;
	if (DisplacementX!=0 || DisplacementY!=0)
	{
		ost << "CCameraFirewireCMU::SetPartialScan() LowerRight position aligned to cell grid unit" << "\n";
		//CError::ShowMessage(IPL_WARNING,ost.str().c_str());
	}
	if(control.Status() != CAM_SUCCESS)
	{
		ost << "CCameraFirewireCMU::SetPartialScan() Error accessing partial scan information." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}		
	m_Height = control.m_height;
	m_Width = control.m_width;
	return true;
}


bool CCameraFirewireCMU::GetPartialScanUnitSize(unsigned int &Horizontal, unsigned int &Vertical)
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::GetPartialScanUnitSize() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (m_Format!=7)
	{
		ost << "CCameraFirewireCMU::GetPartialScanUnitSize() Camera not set to partial scan." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	C1394CameraControlSize &control = m_phCamera->m_controlSize;
	if(control.Status() != CAM_SUCCESS)
	{
		ost << "CCameraFirewireCMU::GetPartialScanUnitSize() Error accessing unit size information." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	Horizontal = control.m_unitH;
	Vertical = control.m_unitV;
	return true;
}


CPoint2D<UINT16> CCameraFirewireCMU::GetMaxPartialScan()
{
	strstream ost;
	CPoint2D<UINT16> MaxWindow(0,0);
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::GetMaxPartialScan() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return MaxWindow;
	}
	if (m_Format!=7)
	{
		ost << "CCameraFirewireCMU::GetMaxPartialScan() Camera not set to partial scan." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return MaxWindow;
	}
	C1394CameraControlSize &control = m_phCamera->m_controlSize;
	if(control.Status() == CAM_SUCCESS)
		MaxWindow.Set(control.m_maxH, control.m_maxV);
	else
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetMaxPartialScan() Error accessing information." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
	}
	return MaxWindow;
}
*/

bool CCameraFirewireCMU::GetColorCodingsAvailable(vector<string>& ColorCodings) const
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::GetColorCodingsAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (m_Format!=7)
	{
		ost << "CCameraFirewireCMU::GetColorCodingsAvailable() Camera not set to partial scan." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	C1394CameraControlSize &control = m_phCamera->m_controlSize;
	if(control.Status() != CAM_SUCCESS)
	{
		ost << "CCameraFirewireCMU::GetColorCodingsAvailable() Error accessing color coding information." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	ColorCodings.clear();
	for(int ccoding = 0; ccoding < 7; ccoding++)
		if(control.m_colorCodes[ccoding])
			ColorCodings.push_back(sFormat7ColorCoding[ccoding]);
		return true;
}

int CCameraFirewireCMU::GetColorCoding() const
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::GetColorCoding() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (m_Format!=7)
	{
		ost << "CCameraFirewireCMU::GetColorCoding() Camera not set to partial scan." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	C1394CameraControlSize &control = m_phCamera->m_controlSize;
	if(control.Status() != CAM_SUCCESS)
	{
		ost << "CCameraFirewireCMU::GetColorCoding() Error accessing color coding information." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_phCamera->m_controlSize.m_colorCode;
}

bool CCameraFirewireCMU::SetColorCoding(unsigned int ColorCoding)
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetColorCoding() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (m_Format!=7)
	{
		ost << "CCameraFirewireCMU::SetColorCoding() Camera not set to partial scan." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	C1394CameraControlSize &control = m_phCamera->m_controlSize;
	if(control.Status() != CAM_SUCCESS)
	{
		ost << "CCameraFirewireCMU::SetColorCoding() Error accessing color coding information." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(ColorCoding>=7 || !control.m_colorCodes[ColorCoding])
	{
		ost << "CCameraFirewireCMU::SetColorCoding() Color coding not valid." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(control.SetColorCode(ColorCoding)!= CAM_SUCCESS)
	{
		ost << "CCameraFirewireCMU::SetColorCoding() Error setting color coding." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	m_BitsPerPixel = Format7ColorCoding[ColorCoding];
	return true;
}


/* *************************** *
* ------ Image Acquire ------ *
* *************************** */


bool CCameraFirewireCMU::Acquire(unsigned char * data) //CStdImage& Image)
{
	bool status = false;
	strstream ost;
	if ((m_QueryCameras==false) && (SettingsInitialized()==true))
	{
		QueryCameras();
		//Sleep(CAM_DELAY_SLEEP);
		SetWithCurrentValues();
		//Sleep(CAM_DELAY_SLEEP);
	}
	else if ((SettingsInitialized()==true) && (ImageCaptureStarted()==false) && 
		(ImageAcquisitionExtendedStarted()==false))
	{
		SetWithCurrentValues();
		//Sleep(CAM_DELAY_SLEEP);
		//Sleep(CAM_DELAY_SLEEP);
	}
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::Acquire() Must call Initialize() first" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(!m_AcquireStarted)
	{	
		StartImageCapture();
	}
	
	
	switch(m_phCamera->CaptureImage()) // edr: Changed from AcquireImage() to CaptureImage()!
	{
	case CAM_SUCCESS:	
		status = true;
		break;			
	case CAM_ERROR_NOT_INITIALIZED:	
		ost << "CCameraFirewireCMU::Acquire() StartImageCapture() has not been successfully called." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		break;
	default:
		ost << "CCameraFirewireCMU::Acquire() Error acquiring frame." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		break;
	}	
	
	
	/* I assume data is width * height
	
	if ((Image.GetWidth()!=m_Width) || (Image.GetHeight()!=m_Height) || (Image.GetBits()!=m_BitsPerPixel))
	{
		if (Image.AllocFast(m_Width,m_Height,m_BitsPerPixel)==false)
		{
			ost << "CCameraFirewire::Acquire() Failed allocating image" << "\n"; 
			//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
			return false;
		}
	}
	*/
	if(status){
		if(m_BitsPerPixel == 8){
			unsigned char *destination = data;
			unsigned char *source = m_phCamera->m_pData;
			
			/*for(int lineNo = 0; lineNo < m_Height; lineNo++)
				//copies a line at a time
				memcpy(&destination[lineNo*m_Width], &source[(m_Height-lineNo-1)*m_Width], m_Width);
			}*/
			
			//memcpy(destination, source, m_Width* m_Height);
		}
//		else if(m_BitsPerPixel == 24)
//		{
//			unsigned char* tempData=(unsigned char*)malloc(m_Width * m_Height * 3);
//			m_phCamera->YUV411toRGB(tempData);
////			m_phCamera->getDIB(tempData);
//			TImage *destination = Image.GetTImagePtr();
//			unsigned char *source = m_phCamera->m_pData;
//			for(int lineNo = 0; lineNo < m_Height; lineNo++)
//				//copies a line at a time
//				memcpy(destination->ppAllScanLines[lineNo], &tempData[(m_Height-lineNo-1)*m_Width*3], m_Width*3);
//			free(tempData);
//		}
		else if(m_BitsPerPixel == 24)
			
			m_phCamera->getDIB(data);
	}
	return status;
}

bool CCameraFirewireCMU::StartImageCapture()
{
	bool status = false;
	strstream ost;
	Sleep(CAM_DELAY_SLEEP);

//	switch(m_phCamera->StartImageAcquisition())
	switch(m_phCamera->StartImageCapture()) // edr: changed from StartImageAcquire() to StartImageCapture()
	{
	case CAM_SUCCESS:
		// capture a dummy image to initialize buffer
		Sleep(CAM_DELAY_SLEEP);
		switch(m_phCamera->CaptureImage()) // edr: Changed from AcquireImage() to CaptureImage()!
		{
		case CAM_SUCCESS:	
			status = true;
			break;			
		case CAM_ERROR_NOT_INITIALIZED:	
			ost << "CCameraFirewireCMU::StartImageCapture() Camera not initialized" << "\n";
			//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
			break;
		default:
			ost << "CCameraFirewireCMU::StartImageCapture() Initialization of image buffer failed" << "\n";
			//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
			break;
		}	
		m_AcquireStarted = true;
		status = true;
		break;
	case CAM_ERROR_NOT_INITIALIZED:
		ost << "CCameraFirewireCMU::StartImageCapture() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		break;
	case CAM_ERROR_INVALID_VIDEO_SETTINGS:
		ost << "CCameraFirewireCMU::StartImageCapture() The current video settings (format, mode, and/or rate) are not supported." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		break;
	case CAM_ERROR_BUSY:
		ost << "CCameraFirewireCMU::StartImageCapture() The camera is already capturing or acquiring images." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		break;
	case CAM_ERROR_INSUFFICIENT_RESOURCES:
		ost << "CCameraFirewireCMU::StartImageCapture() Not enough 1394 bus resoures available to complete the operation." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		break;
	case ERROR_OUTOFMEMORY:
		ost << "CCameraFirewireCMU::StartImageCapture() Out of memory - Allocation of buffers has failed." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		break;
	default:
		ost << "CCameraFirewireCMU::StartImageCapture() Error in device driver." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		break;
	}
	return status;
}

bool CCameraFirewireCMU::StopImageCapture()
{
	bool status = false;
	strstream ost;
	if(!m_AcquireStarted)
	{
		ost << "CCameraFirewireCMU::StopImageCapture() StartImageCapture() ";
		ost << "has not been successfully called." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
//	if (m_phCamera->m_hDeviceCapture==NULL)
//	{
//		// If QueryCameras() has been called, this camera is already stoped
//		// we can check this on the m_hDeviceCapture handle. In this case
//		// we simply set m_AcquireStarted to false
//		m_AcquireStarted = false;
//		return true;
//	}
//	switch(m_phCamera->StopImageAcquisition())
	Sleep(CAM_DELAY_SLEEP);
	switch(m_phCamera->StopImageCapture()) // edr: changed from StopImageAcquisition() to StopImageCapture()
	{
	case CAM_SUCCESS:
		m_AcquireStarted = false;
		status = true;
		break;
	case CAM_ERROR_NOT_INITIALIZED:
		ost << "CCameraFirewireCMU::StopImageCapture() StartImageCapture() has not been successfully called." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		break;
	}
	return status;
}


bool CCameraFirewireCMU::StartImageAcquisitionExtended()
{
	if (ImageCaptureStarted()==true)
	{
		StopImageCapture(); 
	}
	else if (ImageAcquisitionExtendedStarted()==true)
	{
		StopImageAcquisitionExtended();
	}

	strstream ost;
	switch(m_phCamera->StartImageAcquisition())
	{
	case CAM_SUCCESS:
		break;
	case CAM_ERROR_NOT_INITIALIZED:
		ost << "CCameraFirewireCMU::StartImageAcquisitionExtended() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	case CAM_ERROR_INVALID_VIDEO_SETTINGS:
		ost << "CCameraFirewireCMU::StartImageAcquisitionExtended() The current video settings (format, mode, and/or rate) are not supported." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	case CAM_ERROR_BUSY:
		ost << "CCameraFirewireCMU::StartImageAcquisitionExtended() The camera is already capturing or acquiring images." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	case CAM_ERROR_INSUFFICIENT_RESOURCES:
		ost << "CCameraFirewireCMU::StartImageAcquisitionExtended() Not enough 1394 bus resoures available to complete the operation." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	case ERROR_OUTOFMEMORY:
		ost << "CCameraFirewireCMU::StartImageAcquisitionExtended() Out of memory - Allocation of buffers has failed." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	default:
		ost << "CCameraFirewireCMU::StartImageAcquisitionExtended() Error in device driver." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	m_ExtendedAcquireStarted = true;
	return true;
}


bool CCameraFirewireCMU::StopImageAcquisitionExtended()
{

	
	strstream ost;
	if(!m_ExtendedAcquireStarted)
	{
		
		ost << "CCameraFirewireCMU::StopImageAcquisitionExtended() StartImageAcquisitionExtended() ";
		ost << "has not been successfully called." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	
	m_ExtendedAcquireStarted = false;
	return (m_phCamera->StopImageAcquisition()==CAM_SUCCESS);
}


bool CCameraFirewireCMU::AcquireExtended(unsigned char * data)
{
	bool status = false;
	strstream ost;
	if ((m_QueryCameras==false) && (SettingsInitialized()==true))
	{
		QueryCameras();
		Sleep(CAM_DELAY_SLEEP);
		SetWithCurrentValues();
		Sleep(CAM_DELAY_SLEEP);
	}
	else if ((SettingsInitialized()==true) && (ImageCaptureStarted()==false) && 
		(ImageAcquisitionExtendedStarted()==false))
	{
		SetWithCurrentValues();
		Sleep(CAM_DELAY_SLEEP);
		Sleep(CAM_DELAY_SLEEP);
	}
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::AcquireExtended() Must call Initialize() first" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(ImageAcquisitionExtendedStarted()==false)
	{	
		StartImageAcquisitionExtended();
	}
	switch(m_phCamera->AcquireImageEx(TRUE,NULL))
	{
	case CAM_SUCCESS:	
		status = true;
		break;			
	case CAM_ERROR_NOT_INITIALIZED:	
		ost << "CCameraFirewireCMU::AcquireExtended() StartImageCapture() has not been successfully called." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		break;
	default:
		ost << "CCameraFirewireCMU::AcquireExtended() Error acquiring frame." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		break;
	}	
	
	/*if ((Image.GetWidth()!=m_Width) || (Image.GetHeight()!=m_Height) || (Image.GetBits()!=m_BitsPerPixel))
	{
		if (Image.AllocFast(m_Width,m_Height,m_BitsPerPixel)==false)
		{
			ost << "CCameraFirewire::AcquireExtended() Failed allocating image" << "\n"; 
			//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
			return false;
		}
	}
	*/
	
	if(status){
		if(m_BitsPerPixel == 8){
			unsigned char *destination = data; //Image.GetTImagePtr()->pPixelStream;
			unsigned char *source = m_phCamera->m_pData;
			
			/*for(int lineNo = 0; lineNo < m_Height; lineNo++)
				//copies a line at a time
				memcpy(&destination[lineNo*m_Width], &source[(m_Height-lineNo-1)*m_Width], m_Width);
			}
		*/
		memcpy(destination, source, m_Width*m_Height);
		} else if(m_BitsPerPixel == 24)
			m_phCamera->getDIB(data);
	}
	return status;
}


/* *************************** *
* ------ AutoExposure ------- *
* *************************** */


/*Check if camera support AutoExposure*/
bool CCameraFirewireCMU::AutoExposureAvailable() const 
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::AutoExposureAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_AutoExposurePresent;		
}

bool CCameraFirewireCMU::GetAutoExposureAuto() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetAutoExposureAuto() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_AutoExposureAuto;
}

bool CCameraFirewireCMU::SetAutoExposureAuto(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetAutoExposureAuto() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_AutoExposurePresent)
	{
		ost << "CCameraFirewireCMU::SetAutoExposureAuto() AutoExposure not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlAutoExposure.SetAutoMode(Value);
	if (success==CAM_SUCCESS){
		m_AutoExposureAuto = Value;
		return true;
	}
	return false;
}

bool CCameraFirewireCMU::GetAutoExposureOn() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetAutoExposureOn() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_AutoExposureOn;
}

bool CCameraFirewireCMU::SetAutoExposureOn(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetAutoExposureOn() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_AutoExposurePresent)
	{
		ost << "CCameraFirewireCMU::SetAutoExposureOn() AutoExposure not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlAutoExposure.TurnOn(Value);
	if (success==CAM_SUCCESS){
		m_AutoExposureOn = Value;
		return true;
	}
	return false;
}

/*Get camera auto exposure*/
double CCameraFirewireCMU::GetAutoExposure() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetAutoExposure() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_AutoExposurePresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetAutoExposure() AutoExposure not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_AutoExposureValue;
}


double CCameraFirewireCMU::GetAutoExposureMin() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetAutoExposureMin() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_AutoExposurePresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetAutoExposure() AutoExposure not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_AutoExposureMin;
}


double CCameraFirewireCMU::GetAutoExposureMax() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetAutoExposureMax() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_AutoExposurePresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetAutoExposure() AutoExposure not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_AutoExposureMax;
}


double CCameraFirewireCMU::SetAutoExposure(double Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetAutoExposure() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_AutoExposurePresent)
	{
		ost << "CCameraFirewireCMU::SetAutoExposure() AutoExposure not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (Value > m_AutoExposureMax){
		Value = m_AutoExposureMax;
	}
	else if (Value < m_AutoExposureMin){
		Value = m_AutoExposureMin;
	}
	else
		Value=(int)(Value);
	//Call control class update shortcut			
	m_phCamera->SetAutoExposure(Value);
	m_AutoExposureValue = Value;
	if(m_phCamera->m_controlAutoExposure.m_value1==Value)
		return Value;
	return -1;
}


double CCameraFirewireCMU::IncAutoExposure()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::IncAutoExposure() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_AutoExposurePresent)
	{
		ost << "CCameraFirewireCMU::IncAutoExposure() AutoExposure not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	int Val = m_AutoExposureValue;
	Val++;
	if (Val> m_AutoExposureMax){
		Val = m_AutoExposureMax;
	}
	//Call control class update shortcut				
	m_phCamera->SetAutoExposure(Val);
	m_AutoExposureValue = Val;
	if(m_phCamera->m_controlAutoExposure.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::DecAutoExposure()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::DecAutoExposure() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_AutoExposurePresent)
	{
		ost << "CCameraFirewireCMU::DecAutoExposure() AutoExposure not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_AutoExposureValue;
	Val--;
	if (Val < m_AutoExposureMin){
		Val = m_AutoExposureMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetAutoExposure(Val);
	m_AutoExposureValue = Val;
	if(m_phCamera->m_controlAutoExposure.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::AutoExposureDouble()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::AutoExposureDouble() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available
	if (!m_AutoExposurePresent)
	{
		ost << "CCameraFirewireCMU::AutoExposureDouble() AutoExposure not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	} 
	
	int Val = m_AutoExposureValue*2;
	if (Val > m_AutoExposureMax){
		Val = m_AutoExposureMax;
	}
	//Call control class update shortcut			
	m_phCamera->SetAutoExposure(Val);
	m_AutoExposureValue = Val;
	if(m_phCamera->m_controlAutoExposure.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::AutoExposureHalf()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::AutoExposureHalf() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_AutoExposurePresent)
	{
		ost << "CCameraFirewireCMU::AutoExposureHalf() AutoExposure not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_AutoExposureValue/2;
	if (Val < m_AutoExposureMin){
		Val = m_AutoExposureMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetAutoExposure(Val);
	m_AutoExposureValue = Val;
	if(m_phCamera->m_controlAutoExposure.m_value1==Val)
		return Val;
	return -1;
}

bool CCameraFirewireCMU::ReadAutoExposure()
{
	m_phCamera->m_controlAutoExposure.Inquire();
	m_AutoExposurePresent = m_phCamera->m_controlAutoExposure.m_present;
	if (m_AutoExposurePresent)
	{
		m_AutoExposureOn = m_phCamera->m_controlAutoExposure.m_statusOnOff;
		m_AutoExposureAuto = m_phCamera->m_controlAutoExposure.m_statusAutoManual;
		m_AutoExposureValue = m_phCamera->m_controlAutoExposure.m_value1;
		m_AutoExposureMin = m_phCamera->m_controlAutoExposure.m_min;
		m_AutoExposureMax = m_phCamera->m_controlAutoExposure.m_max;
		return true;
	}
	m_AutoExposureValue = -1;
	m_AutoExposureMin = -1;
	m_AutoExposureMax = -1;
	return false;
}

/* *************************** *
* ------- Brightness -------- *
* *************************** */


/*Check if camera support Brightness*/
bool CCameraFirewireCMU::BrightnessAvailable() const 
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::BrightnessAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_BrightnessPresent;		
}

double CCameraFirewireCMU::GetBrightness() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetBrightness() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_BrightnessPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetBrightness() Brightness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_BrightnessValue;
}


double CCameraFirewireCMU::GetBrightnessMin() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetBrightnessMin() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_BrightnessPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetBrightness() Brightness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_BrightnessMin;
}


double CCameraFirewireCMU::GetBrightnessMax() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetBrightnessMax() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_BrightnessPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetBrightness() Brightness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_BrightnessMax;
}


double CCameraFirewireCMU::SetBrightness(double Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetBrightness() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_BrightnessPresent)
	{
		ost << "CCameraFirewireCMU::SetBrightness() Brightness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (Value > m_BrightnessMax){
		Value = m_BrightnessMax;
	}
	else if (Value < m_BrightnessMin){
		Value = m_BrightnessMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetBrightness(Value);
	m_BrightnessValue = Value;
	if(m_phCamera->m_controlBrightness.m_value1==Value)
		return Value;
	return -1;
}


double CCameraFirewireCMU::IncBrightness()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::IncBrightness() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_BrightnessPresent)
	{
		ost << "CCameraFirewireCMU::IncBrightness() Brightness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	int Val = m_BrightnessValue;
	Val++;
	if (Val> m_BrightnessMax){
		Val = m_BrightnessMax;
	}
	//Call control class update shortcut				
	m_phCamera->SetBrightness(Val);
	m_BrightnessValue = Val;
	if(m_phCamera->m_controlBrightness.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::DecBrightness()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::DecBrightness() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_BrightnessPresent)
	{
		ost << "CCameraFirewireCMU::DecBrightness() Brightness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_BrightnessValue;
	Val--;
	if (Val < m_BrightnessMin){
		Val = m_BrightnessMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetBrightness(Val);
	m_BrightnessValue = Val;
	if(m_phCamera->m_controlBrightness.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::BrightnessDouble()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::BrightnessDouble() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available
	if (!m_BrightnessPresent)
	{
		ost << "CCameraFirewireCMU::BrightnessDouble() Brightness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	} 
	
	int Val = m_BrightnessValue*2;
	if (Val > m_BrightnessMax){
		Val = m_BrightnessMax;
	}
	//Call control class update shortcut			
	m_phCamera->SetBrightness(Val);
	m_BrightnessValue = Val;
	if(m_phCamera->m_controlBrightness.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::BrightnessHalf()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::BrightnessHalf() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_BrightnessPresent)
	{
		ost << "CCameraFirewireCMU::BrightnessHalf() Brightness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_BrightnessValue/2;
	if (Val < m_BrightnessMin){
		Val = m_BrightnessMin;
	}
	
	//Call control class update shortcut			
	m_phCamera->SetBrightness(Val);
	m_BrightnessValue = Val;
	if(m_phCamera->m_controlBrightness.m_value1==Val)
		return Val;
	return -1;
}

bool CCameraFirewireCMU::ReadBrightness()
{
	m_phCamera->m_controlBrightness.Inquire();
	m_BrightnessPresent = m_phCamera->m_controlBrightness.m_present;
	if (m_BrightnessPresent)
	{
		m_BrightnessOn = m_phCamera->m_controlBrightness.m_statusOnOff;
		m_BrightnessAuto = m_phCamera->m_controlBrightness.m_statusAutoManual;
		m_BrightnessValue = m_phCamera->m_controlBrightness.m_value1;
		m_BrightnessMin = m_phCamera->m_controlBrightness.m_min;
		m_BrightnessMax = m_phCamera->m_controlBrightness.m_max;
		return true;
	}
	m_BrightnessMin = -1;
	m_BrightnessMax = -1;
	return false;
}

bool CCameraFirewireCMU::GetBrightnessAuto() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetBrightnessAuto() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_BrightnessAuto;
	
}

bool CCameraFirewireCMU::SetBrightnessAuto(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetBrightnessAuto() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_BrightnessPresent)
	{
		ost << "CCameraFirewireCMU::SetBrightnessAuto() Brightness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlBrightness.SetAutoMode(Value);
	if (success==CAM_SUCCESS){
		m_BrightnessAuto = Value;
		return true;
	}
	return false;
}

bool CCameraFirewireCMU::GetBrightnessOn() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetBrightnessOn() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_BrightnessOn;
}

bool CCameraFirewireCMU::SetBrightnessOn(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetBrightnessOn() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_BrightnessPresent)
	{
		ost << "CCameraFirewireCMU::SetBrightnessOn() Brightness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlBrightness.TurnOn(Value);
	if (success==CAM_SUCCESS){
		m_BrightnessOn = Value;
		return true;
	}
	return false;
}

/* *************************** *
* --------- Focus ----------- *
* *************************** */


/*Check if camera support Focus*/
bool CCameraFirewireCMU::FocusAvailable() const 
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::FocusAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_FocusPresent;		
}

double CCameraFirewireCMU::GetFocus() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetFocus() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_FocusPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetFocus() Focus not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_FocusValue;
}


double CCameraFirewireCMU::GetFocusMin() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetFocusMin() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_FocusPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetFocus() Focus not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_FocusMin;
}


double CCameraFirewireCMU::GetFocusMax() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetFocusMax() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_FocusPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetFocus() Focus not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_FocusMax;
}


double CCameraFirewireCMU::SetFocus(double Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetFocus() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_FocusPresent)
	{
		ost << "CCameraFirewireCMU::SetFocus() Focus not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (Value > m_FocusMax){
		Value = m_FocusMax;
	}
	else if (Value < m_FocusMin){
		Value = m_FocusMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetFocus(Value);
	m_FocusValue = Value;
	if(m_phCamera->m_controlFocus.m_value1==Value)
		return Value;
	return -1;
}


double CCameraFirewireCMU::IncFocus()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::IncFocus() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_FocusPresent)
	{
		ost << "CCameraFirewireCMU::IncFocus() Focus not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	int Val = m_FocusValue;
	Val++;
	if (Val> m_FocusMax){
		Val = m_FocusMax;
	}
	//Call control class update shortcut				
	m_phCamera->SetFocus(Val);
	m_FocusValue = Val;
	if(m_phCamera->m_controlFocus.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::DecFocus()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::DecFocus() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_FocusPresent)
	{
		ost << "CCameraFirewireCMU::DecFocus() Focus not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_FocusValue;
	Val--;
	if (Val < m_FocusMin){
		Val = m_FocusMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetFocus(Val);
	m_FocusValue = Val;
	if(m_phCamera->m_controlFocus.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::FocusDouble()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::FocusDouble() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available
	if (!m_FocusPresent)
	{
		ost << "CCameraFirewireCMU::FocusDouble() Focus not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	} 
	
	int Val = m_FocusValue*2;
	if (Val > m_FocusMax){
		Val = m_FocusMax;
	}
	//Call control class update shortcut			
	m_phCamera->SetFocus(Val);
	m_FocusValue = Val;
	if(m_phCamera->m_controlFocus.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::FocusHalf()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::FocusHalf() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_FocusPresent)
	{
		ost << "CCameraFirewireCMU::FocusHalf() Focus not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_FocusValue/2;
	if (Val < m_FocusMin){
		Val = m_FocusMin;
	}	
	
	//Call control class update shortcut			
	m_phCamera->SetFocus(Val);
	m_FocusValue = Val;
	if(m_phCamera->m_controlFocus.m_value1==Val)
		return Val;
	return -1;
}

bool CCameraFirewireCMU::ReadFocus()
{
	m_phCamera->m_controlFocus.Inquire();
	m_FocusPresent = m_FocusPresent;
	if (m_FocusPresent)
	{
		m_FocusAuto = m_phCamera->m_controlFocus.m_statusAutoManual;
		m_FocusValue = m_phCamera->m_controlFocus.m_value1;
		m_FocusMin = m_phCamera->m_controlFocus.m_min;
		m_FocusMax = m_phCamera->m_controlFocus.m_max;
		return true;
	}
	m_FocusValue = -1;
	m_FocusMin = -1;
	m_FocusMax = -1;
	return false;
}

bool CCameraFirewireCMU::GetFocusOn() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetFocusOn() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_FocusOn;
}

bool CCameraFirewireCMU::SetFocusOn(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetFocusOn() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_FocusPresent)
	{
		ost << "CCameraFirewireCMU::SetFocusOn() Focus not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlFocus.TurnOn(Value);
	if (success==CAM_SUCCESS)
	{
		m_FocusOn = Value;
		return true;
	}
	return false;
}

/* *************************** *
* ---------- Gain ----------- *
* *************************** */


/*Check if camera support Gain*/
bool CCameraFirewireCMU::GainAvailable() const 
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GainAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_GainPresent;		
}

double CCameraFirewireCMU::GetGain() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetGain() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_GainPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetGain() Gain not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_GainValue;
}


double CCameraFirewireCMU::GetGainMin() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetGainMin() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_GainPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetGain() Gain not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_GainMin;
}


double CCameraFirewireCMU::GetGainMax() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetGainMax() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_GainPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetGain() Gain not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_GainMax;
}


double CCameraFirewireCMU::SetGain(double Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetGain() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_GainPresent)
	{
		ost << "CCameraFirewireCMU::SetGain() Gain not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (Value > m_GainMax){
		Value = m_GainMax;
	}
	else if (Value < m_GainMin){
		Value = m_GainMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetGain(Value);
	m_GainValue = Value;
	if(m_phCamera->m_controlGain.m_value1==Value)
		return Value;
	return -1;
}


double CCameraFirewireCMU::IncGain()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::IncGain() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_GainPresent)
	{
		ost << "CCameraFirewireCMU::IncGain() Gain not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	int Val = m_GainValue;
	Val++;
	if (Val> m_GainMax){
		Val = m_GainMax;
	}
	//Call control class update shortcut				
	m_phCamera->SetGain(Val);
	m_GainValue = Val;
	if(m_phCamera->m_controlGain.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::DecGain()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::DecGain() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_GainPresent)
	{
		ost << "CCameraFirewireCMU::DecGain() Gain not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_GainValue;
	Val--;
	if (Val < m_GainMin){
		Val = m_GainMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetGain(Val);
	m_GainValue = Val;
	if(m_phCamera->m_controlGain.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::GainDouble()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::GainDouble() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available
	if (!m_GainPresent)
	{
		ost << "CCameraFirewireCMU::GainDouble() Gain not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	} 
	
	int Val = m_GainValue*2;
	if (Val > m_GainMax){
		Val = m_GainMax;
	}
	//Call control class update shortcut			
	m_phCamera->SetGain(Val);
	m_GainValue = Val;
	if(m_phCamera->m_controlGain.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::GainHalf()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::GainHalf() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_GainPresent)
	{
		ost << "CCameraFirewireCMU::GainHalf() Gain not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_GainValue/2;
	if (Val < m_GainMin){
		Val = m_GainMin;
	}
	
	//Call control class update shortcut			
	m_phCamera->SetGain(Val);
	m_GainValue = Val;
	if(m_phCamera->m_controlGain.m_value1==Val)
		return Val;
	return -1;
}

bool CCameraFirewireCMU::ReadGain()
{
	m_phCamera->m_controlGain.Inquire();
	m_GainPresent = m_phCamera->m_controlGain.m_present;
	if (m_GainPresent)
	{	
		m_GainAuto = m_phCamera->m_controlGain.m_statusAutoManual;
		m_GainValue = m_phCamera->m_controlGain.m_value1;
		m_GainMin = m_phCamera->m_controlGain.m_min;
		m_GainMax = m_phCamera->m_controlGain.m_max;
		return true;
	}
	m_GainValue = -1;
	m_GainMin = -1;
	m_GainMax = -1;
	return false;
}

bool CCameraFirewireCMU::GetGainAuto() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetGainAuto() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_GainAuto;
	
}

bool CCameraFirewireCMU::SetGainAuto(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetGainAuto() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_GainPresent)
	{
		ost << "CCameraFirewireCMU::SetGainAuto() Gain not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlGain.SetAutoMode(Value);
	if (success==CAM_SUCCESS){
		m_GainAuto = Value;
		return true;
	}
	return false;
}

bool CCameraFirewireCMU::GetGainOn() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetGainOn() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_GainOn;
}

bool CCameraFirewireCMU::SetGainOn(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetGainOn() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_GainPresent)
	{
		ost << "CCameraFirewireCMU::SetGainOn() Gain not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlGain.TurnOn(Value);
	if (success==CAM_SUCCESS){
		m_GainOn = Value;
		return true;
	}
	return false;
}

/* *************************** *
* --------- Gamma ----------- *
* *************************** */


/*Check if camera support Gamma*/
bool CCameraFirewireCMU::GammaAvailable() const 
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GammaAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_GammaPresent;
}

double CCameraFirewireCMU::GetGamma() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetGamma() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_GammaPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetGamma() Gamma not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_GammaValue;
}


double CCameraFirewireCMU::GetGammaMin() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetGammaMin() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_GammaPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetGamma() Gamma not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_GammaMin;
}


double CCameraFirewireCMU::GetGammaMax() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetGammaMax() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_GammaPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetGamma() Gamma not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_GammaMax;
}


double CCameraFirewireCMU::SetGamma(double Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetGamma() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_GammaPresent)
	{
		ost << "CCameraFirewireCMU::SetGamma() Gamma not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (Value > m_GammaMax){
		Value = m_GammaMax;
	}
	else if (Value < m_GammaMin){
		Value = m_GammaMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetGamma(Value);
	m_GammaValue = Value;
	if(m_phCamera->m_controlGamma.m_value1==Value)
		return Value;
	return -1;
}


double CCameraFirewireCMU::IncGamma()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::IncGamma() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_GammaPresent)
	{
		ost << "CCameraFirewireCMU::IncGamma() Gamma not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	int Val = m_GammaValue;
	Val++;
	if (Val> m_GammaMax){
		Val = m_GammaMax;
	}
	//Call control class update shortcut				
	m_phCamera->SetGamma(Val);
	m_GammaValue = Val;
	if(m_phCamera->m_controlGamma.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::DecGamma()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::DecGamma() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_GammaPresent)
	{
		ost << "CCameraFirewireCMU::DecGamma() Gamma not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_GammaValue;
	Val--;
	if (Val < m_GammaMin){
		Val = m_GammaMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetGamma(Val);
	m_GammaValue = Val;
	if(m_phCamera->m_controlGamma.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::GammaDouble()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::GammaDouble() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available
	if (!m_GammaPresent)
	{
		ost << "CCameraFirewireCMU::GammaDouble() Gamma not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	} 
	
	int Val = m_GammaValue*2;
	if (Val > m_GammaMax){
		Val = m_GammaMax;
	}
	//Call control class update shortcut			
	m_phCamera->SetGamma(Val);
	m_GammaValue = Val;
	if(m_phCamera->m_controlGamma.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::GammaHalf()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::GammaHalf() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_GammaPresent)
	{
		ost << "CCameraFirewireCMU::GammaHalf() Gamma not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_GammaValue/2;
	if (Val < m_GammaMin){
		Val = m_GammaMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetGamma(Val);
	m_GammaValue = Val;
	if(m_phCamera->m_controlGamma.m_value1==Val)
		return Val;
	return -1;
}

bool CCameraFirewireCMU::ReadGamma()
{
	m_phCamera->m_controlGamma.Inquire();
	m_GammaPresent = m_phCamera->m_controlGamma.m_present;
	if (m_GammaPresent)
	{
		m_GammaAuto = m_phCamera->m_controlGamma.m_statusAutoManual;
		m_GammaValue = m_phCamera->m_controlGamma.m_value1;
		m_GammaMin = m_phCamera->m_controlGamma.m_min;
		m_GammaMax = m_phCamera->m_controlGamma.m_max;
		return true;
	}
	m_GammaValue = -1;
	m_GammaMin = -1;
	m_GammaMax = -1;
	return false;
}

bool CCameraFirewireCMU::GetGammaOn() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetGammaOn() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_GammaOn;
}

bool CCameraFirewireCMU::SetGammaOn(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetGammaOn() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_GammaPresent)
	{
		ost << "CCameraFirewireCMU::SetGammaOn() Gamma not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlGamma.TurnOn(Value);
	if (success==CAM_SUCCESS){
		m_GammaOn = Value;
		return true;
	}
	return false;
}

/* *************************** *
* ----------- Hue ----------- *
* *************************** */


/*Check if camera support Hue*/
bool CCameraFirewireCMU::HueAvailable() const 
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::HueAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_HuePresent;		
}

double CCameraFirewireCMU::GetHue() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetHue() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_HuePresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetHue() Hue not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_HueValue;
}


double CCameraFirewireCMU::GetHueMin() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetHueMin() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_HuePresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetHue() Hue not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_HueMin;
}


double CCameraFirewireCMU::GetHueMax() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetHueMax() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_HuePresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetHue() Hue not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_HueMax;
}


double CCameraFirewireCMU::SetHue(double Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetHue() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_HuePresent)
	{
		ost << "CCameraFirewireCMU::SetHue() Hue not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (Value > m_HueMax){
		Value = m_HueMax;
	}
	else if (Value < m_HueMin){
		Value = m_HueMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetHue(Value);
	m_HueValue = Value;
	if(m_phCamera->m_controlHue.m_value1==Value)
		return Value;
	return -1;
}


double CCameraFirewireCMU::IncHue()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::IncHue() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_HuePresent)
	{
		ost << "CCameraFirewireCMU::IncHue() Hue not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	int Val = m_HueValue;
	Val++;
	if (Val> m_HueMax){
		Val = m_HueMax;
	}
	//Call control class update shortcut				
	m_phCamera->SetHue(Val);
	m_HueValue = Val;
	if(m_phCamera->m_controlHue.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::DecHue()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::DecHue() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_HuePresent)
	{
		ost << "CCameraFirewireCMU::DecHue() Hue not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_HueValue;
	Val--;
	if (Val < m_HueMin){
		Val = m_HueMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetHue(Val);
	m_HueValue = Val;
	if(m_phCamera->m_controlHue.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::HueDouble()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::HueDouble() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available
	if (!m_HuePresent)
	{
		ost << "CCameraFirewireCMU::HueDouble() Hue not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	} 
	
	int Val = m_HueValue*2;
	if (Val > m_HueMax){
		Val = m_HueMax;
	}
	//Call control class update shortcut			
	m_phCamera->SetHue(Val);
	m_HueValue = Val;
	if(m_phCamera->m_controlHue.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::HueHalf()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::HueHalf() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_HuePresent)
	{
		ost << "CCameraFirewireCMU::HueHalf() Hue not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_HueValue/2;
	if (Val < m_HueMin){
		Val = m_HueMin;
	}
	//Call control class update shortcut						
	m_phCamera->SetHue(Val);
	m_HueValue = Val;
	if(m_phCamera->m_controlHue.m_value1==Val)
		return Val;
	return -1;
}

bool CCameraFirewireCMU::ReadHue()
{
	m_phCamera->m_controlHue.Inquire();
	m_HuePresent = m_phCamera->m_controlHue.m_present;
	if (m_HuePresent)
	{
		m_HueAuto = m_phCamera->m_controlHue.m_statusAutoManual;
		m_HueValue = m_phCamera->m_controlHue.m_value1;
		m_HueMin = m_phCamera->m_controlHue.m_min;
		m_HueMax = m_phCamera->m_controlHue.m_max;
		return true;
	}
	m_HueValue = -1;
	m_HueMin = -1;
	m_HueMax = -1;
	return false;
}

bool CCameraFirewireCMU::GetHueOn() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetHueOn() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_HueOn;
}

bool CCameraFirewireCMU::SetHueOn(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetHueOn() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_HuePresent)
	{
		ost << "CCameraFirewireCMU::SetHueOn() Hue not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlHue.TurnOn(Value);
	if (success==CAM_SUCCESS){
		m_HueOn = Value;
		return true;
	}
	return false;
}

/* *************************** *
* ---------- Iris ----------- *
* *************************** */

/*Check if camera support Iris*/
bool CCameraFirewireCMU::IrisAvailable() const 
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::IrisAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_IrisPresent;		
}


double CCameraFirewireCMU::GetIris() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetIris() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_IrisPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetIris() Iris not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_IrisValue;
}


double CCameraFirewireCMU::GetIrisMin() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetIrisMin() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_IrisPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetIris() Iris not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_IrisMin;
}


double CCameraFirewireCMU::GetIrisMax() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetIrisMax() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_IrisPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetIris() Iris not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_IrisMax;
}


double CCameraFirewireCMU::SetIris(double Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetIris() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_IrisPresent)
	{
		ost << "CCameraFirewireCMU::SetIris() Iris not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (Value > m_IrisMax){
		Value = m_IrisMax;
	}
	else if (Value < m_IrisMin){
		Value = m_IrisMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetIris(Value);
	m_IrisValue = Value;
	if(m_phCamera->m_controlIris.m_value1==Value)
		return Value;
	return -1;
}


double CCameraFirewireCMU::IncIris()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::IncIris() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_IrisPresent)
	{
		ost << "CCameraFirewireCMU::IncIris() Iris not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	int Val = m_IrisValue;
	Val++;
	if (Val> m_IrisMax){
		Val = m_IrisMax;
	}
	//Call control class update shortcut				
	m_phCamera->SetIris(Val);
	m_IrisValue = Val;
	if(m_phCamera->m_controlIris.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::DecIris()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::DecIris() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_IrisPresent)
	{
		ost << "CCameraFirewireCMU::DecIris() Iris not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_IrisValue;
	Val--;
	if (Val < m_IrisMin){
		Val = m_IrisMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetIris(Val);
	m_IrisValue = Val;
	if(m_phCamera->m_controlIris.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::IrisDouble()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::IrisDouble() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available
	if (!m_IrisPresent)
	{
		ost << "CCameraFirewireCMU::IrisDouble() Iris not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	} 
	
	int Val = m_IrisValue*2;
	if (Val > m_IrisMax){
		Val = m_IrisMax;
	}
	//Call control class update shortcut			
	m_phCamera->SetIris(Val);
	m_IrisValue = Val;
	if(m_phCamera->m_controlIris.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::IrisHalf()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::IrisHalf() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_IrisPresent)
	{
		ost << "CCameraFirewireCMU::IrisHalf() Iris not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_IrisValue/2;
	if (Val < m_IrisMin){
		Val = m_IrisMin;
	}
	//Call control class update shortcut						
	m_phCamera->SetIris(Val);
	m_IrisValue = Val;
	if(m_phCamera->m_controlIris.m_value1==Val)
		return Val;
	return -1;
}

bool CCameraFirewireCMU::ReadIris()
{
	m_phCamera->m_controlIris.Inquire();
	m_IrisPresent = m_phCamera->m_controlIris.m_present;
	if (m_IrisPresent)
	{
		m_IrisAuto = m_phCamera->m_controlIris.m_statusAutoManual;
		m_IrisValue = m_phCamera->m_controlIris.m_value1;
		m_IrisMin = m_phCamera->m_controlIris.m_min;
		m_IrisMax = m_phCamera->m_controlIris.m_max;
		return true;
	}
	m_IrisValue = -1;
	m_IrisMin = -1;
	m_IrisMax = -1;
	return false;
}

bool CCameraFirewireCMU::GetIrisAuto() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetIrisAuto() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_IrisAuto;
	
}

bool CCameraFirewireCMU::SetIrisAuto(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetIrisAuto() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_IrisPresent)
	{
		ost << "CCameraFirewireCMU::SetIrisAuto() Iris not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlIris.SetAutoMode(Value);
	if (success==CAM_SUCCESS){
		m_IrisAuto = Value;
		return true;
	}
	return false;
}

bool CCameraFirewireCMU::GetIrisOn() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetIrisOn() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_IrisOn;
}

bool CCameraFirewireCMU::SetIrisOn(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetIrisOn() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_IrisPresent)
	{
		ost << "CCameraFirewireCMU::SetIrisOn() Iris not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlIris.TurnOn(Value);
	if (success==CAM_SUCCESS){
		m_IrisOn = Value;
		return true;
	}
	return false;
}

/* *************************** *
* ------- Saturation -------- *
* *************************** */

/*Check if camera support Saturation*/
bool CCameraFirewireCMU::SaturationAvailable() const 
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::SaturationAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_SaturationPresent;		
}


double CCameraFirewireCMU::GetSaturation() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSaturation() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_SaturationPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSaturation() Saturation not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_SaturationValue;
}


double CCameraFirewireCMU::GetSaturationMin() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSaturationMin() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_SaturationPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSaturation() Saturation not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_SaturationMin;
}


double CCameraFirewireCMU::GetSaturationMax() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSaturationMax() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_SaturationPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSaturation() Saturation not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_SaturationMax;
}


double CCameraFirewireCMU::SetSaturation(double Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetSaturation() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_SaturationPresent)
	{
		ost << "CCameraFirewireCMU::SetSaturation() Saturation not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (Value > m_SaturationMax){
		Value = m_SaturationMax;
	}
	else if (Value < m_SaturationMin){
		Value = m_SaturationMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetSaturation(Value);
	m_SaturationValue = Value;
	if(m_phCamera->m_controlSaturation.m_value1==Value)
		return Value;
	return -1;
}


double CCameraFirewireCMU::IncSaturation()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::IncSaturation() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_SaturationPresent)
	{
		ost << "CCameraFirewireCMU::IncSaturation() Saturation not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	int Val = m_SaturationValue;
	Val++;
	if (Val> m_SaturationMax){
		Val = m_SaturationMax;
	}
	//Call control class update shortcut				
	m_phCamera->SetSaturation(Val);
	m_SaturationValue = Val;
	if(m_phCamera->m_controlSaturation.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::DecSaturation()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::DecSaturation() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_SaturationPresent)
	{
		ost << "CCameraFirewireCMU::DecSaturation() Saturation not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_SaturationValue;
	Val--;
	if (Val < m_SaturationMin){
		Val = m_SaturationMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetSaturation(Val);
	m_SaturationValue = Val;
	if(m_phCamera->m_controlSaturation.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::SaturationDouble()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SaturationDouble() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available
	if (!m_SaturationPresent)
	{
		ost << "CCameraFirewireCMU::SaturationDouble() Saturation not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	} 
	
	int Val = m_SaturationValue*2;
	if (Val > m_SaturationMax){
		Val = m_SaturationMax;
	}
	//Call control class update shortcut			
	m_phCamera->SetSaturation(Val);
	m_SaturationValue = Val;
	if(m_phCamera->m_controlSaturation.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::SaturationHalf()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SaturationHalf() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_SaturationPresent)
	{
		ost << "CCameraFirewireCMU::SaturationHalf() Saturation not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_SaturationValue/2;
	if (Val < m_SaturationMin){
		Val = m_SaturationMin;
	}
	//Call control class update shortcut					
	m_phCamera->SetSaturation(Val);
	m_SaturationValue = Val;
	if(m_phCamera->m_controlSaturation.m_value1==Val)
		return Val;
	return -1;
}

bool CCameraFirewireCMU::ReadSaturation()
{
	m_phCamera->m_controlSaturation.Inquire();
	m_SaturationPresent = m_phCamera->m_controlSaturation.m_present;
	if (m_SaturationPresent)
	{
		m_SaturationAuto = m_phCamera->m_controlSaturation.m_statusAutoManual;
		m_SaturationValue = m_phCamera->m_controlSaturation.m_value1;
		m_SaturationMin = m_phCamera->m_controlSaturation.m_min;
		m_SaturationMax = m_phCamera->m_controlSaturation.m_max;
		return true;
	}
	m_SaturationValue = -1;
	m_SaturationMin = -1;
	m_SaturationMax = -1;
	return false;
}

bool CCameraFirewireCMU::GetSaturationAuto() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSaturationAuto() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_SaturationAuto;
	
}

bool CCameraFirewireCMU::SetSaturationAuto(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetSaturationAuto() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_SaturationPresent)
	{
		ost << "CCameraFirewireCMU::SetSaturationAuto() Saturation not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlSaturation.SetAutoMode(Value);
	if (success==CAM_SUCCESS){
		m_SaturationAuto = Value;
		return true;
	}
	return false;
}

bool CCameraFirewireCMU::GetSaturationOn() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSaturationOn() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_SaturationOn;
}

bool CCameraFirewireCMU::SetSaturationOn(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetSaturationOn() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_SaturationPresent)
	{
		ost << "CCameraFirewireCMU::SetSaturationOn() Saturation not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlSaturation.TurnOn(Value);
	if (success==CAM_SUCCESS){
		m_SaturationOn = Value;
		return true;
	}
	return false;
}

/* *************************** *
* -------- Sharpness -------- *
* *************************** */


/*Check if camera support Sharpness*/
bool CCameraFirewireCMU::SharpnessAvailable() const 
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::SharpnessAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_SharpnessPresent;		
}

double CCameraFirewireCMU::GetSharpness() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSharpness() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_SharpnessPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSharpness() Sharpness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_SharpnessValue;
}


double CCameraFirewireCMU::GetSharpnessMin() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSharpnessMin() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_SharpnessPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSharpness() Sharpness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_SharpnessMin;
}


double CCameraFirewireCMU::GetSharpnessMax() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSharpnessMax() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_SharpnessPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSharpness() Sharpness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_SharpnessMax;
}


double CCameraFirewireCMU::SetSharpness(double Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetSharpness() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_SharpnessPresent)
	{
		ost << "CCameraFirewireCMU::SetSharpness() Sharpness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (Value > m_SharpnessMax){
		Value = m_SharpnessMax;
	}
	else if (Value < m_SharpnessMin){
		Value = m_SharpnessMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetSharpness(Value);
	m_SharpnessValue = Value;
	if(m_phCamera->m_controlSharpness.m_value1==Value)
		return Value;
	return -1;
}


double CCameraFirewireCMU::IncSharpness()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::IncSharpness() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_SharpnessPresent)
	{
		ost << "CCameraFirewireCMU::IncSharpness() Sharpness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	int Val = m_SharpnessValue;
	Val++;
	if (Val> m_SharpnessMax){
		Val = m_SharpnessMax;
	}
	//Call control class update shortcut				
	m_phCamera->SetSharpness(Val);
	m_SharpnessValue = Val;
	if(m_phCamera->m_controlSharpness.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::DecSharpness()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::DecSharpness() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_SharpnessPresent)
	{
		ost << "CCameraFirewireCMU::DecSharpness() Sharpness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_SharpnessValue;
	Val--;
	if (Val < m_SharpnessMin){
		Val = m_SharpnessMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetSharpness(Val);
	m_SharpnessValue = Val;
	if(m_phCamera->m_controlSharpness.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::SharpnessDouble()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SharpnessDouble() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available
	if (!m_SharpnessPresent)
	{
		ost << "CCameraFirewireCMU::SharpnessDouble() Sharpness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	} 
	
	int Val = m_SharpnessValue*2;
	if (Val > m_SharpnessMax){
		Val = m_SharpnessMax;
	}
	//Call control class update shortcut			
	m_phCamera->SetSharpness(Val);
	m_SharpnessValue = Val;
	if(m_phCamera->m_controlSharpness.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::SharpnessHalf()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SharpnessHalf() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_SharpnessPresent)
	{
		ost << "CCameraFirewireCMU::SharpnessHalf() Sharpness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_SharpnessValue/2;
	if (Val < m_SharpnessMin){
		Val = m_SharpnessMin;
	}
	//Call control class update shortcut				
	m_phCamera->SetSharpness(Val);
	m_SharpnessValue = Val;
	if(m_phCamera->m_controlSharpness.m_value1==Val)
		return Val;
	return -1;
}

bool CCameraFirewireCMU::ReadSharpness()
{
	m_phCamera->m_controlSharpness.Inquire();
	m_SharpnessPresent = m_phCamera->m_controlSharpness.m_present;
	if (m_SharpnessPresent)
	{
		m_SharpnessAuto = m_phCamera->m_controlSharpness.m_statusAutoManual;
		m_SharpnessValue = m_phCamera->m_controlSharpness.m_value1;
		m_SharpnessMin = m_phCamera->m_controlSharpness.m_min;
		m_SharpnessMax = m_phCamera->m_controlSharpness.m_max;
		return true;
	}
	m_SharpnessValue = -1;
	m_SharpnessMin = -1;
	m_SharpnessMax = -1;
	return false;
}

bool CCameraFirewireCMU::GetSharpnessAuto() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSharpnessAuto() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_SharpnessAuto;
	
}

bool CCameraFirewireCMU::SetSharpnessAuto(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetSharpnessAuto() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_SharpnessPresent)
	{
		ost << "CCameraFirewireCMU::SetSharpnessAuto() Sharpness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlSharpness.SetAutoMode(Value);
	if (success==CAM_SUCCESS){
		m_SharpnessAuto = Value;
		return true;
	}
	return false;
}

bool CCameraFirewireCMU::GetSharpnessOn() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetSharpnessOn() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_SharpnessOn;
}

bool CCameraFirewireCMU::SetSharpnessOn(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetSharpnessOn() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_SharpnessPresent)
	{
		ost << "CCameraFirewireCMU::SetSharpnessOn() Sharpness not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlSharpness.TurnOn(Value);
	if (success==CAM_SUCCESS){
		m_SharpnessOn = Value;
		return true;
	}
	return false;
}

/* *************************** *
* --------- Shutter --------- *
* *************************** */

/*Check if camera support Shutter*/
bool CCameraFirewireCMU::ShutterAvailable() const 
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::ShutterAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_ShutterPresent;		
}


double CCameraFirewireCMU::GetShutter() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetShutter() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_ShutterPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetShutter() Shutter not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_ShutterValue;
}


double CCameraFirewireCMU::GetShutterMin() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetShutterMin() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_ShutterPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetShutter() Shutter not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_ShutterMin;
}


double CCameraFirewireCMU::GetShutterMax() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetShutterMax() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_ShutterPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetShutter() Shutter not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_ShutterMax;
}


double CCameraFirewireCMU::SetShutter(double Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetShutter() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_ShutterPresent)
	{
		ost << "CCameraFirewireCMU::SetShutter() Shutter not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (Value > m_ShutterMax){
		Value = m_ShutterMax;
	}
	else if (Value < m_ShutterMin){
		Value = m_ShutterMin;
	}
	else
		Value=(int)(Value);
	//Call control class update shortcut			
	m_phCamera->SetShutter(Value);
	m_ShutterValue = Value;
	if(m_phCamera->m_controlShutter.m_value1==Value)
		return Value;
	return -1;
}


double CCameraFirewireCMU::IncShutter()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::IncShutter() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_ShutterPresent)
	{
		ost << "CCameraFirewireCMU::IncShutter() Shutter not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	int Val = m_ShutterValue;
	Val++;
	if (Val> m_ShutterMax){
		Val = m_ShutterMax;
	}
	//Call control class update shortcut				
	m_phCamera->SetShutter(Val);
	m_ShutterValue = Val;
	if(m_phCamera->m_controlShutter.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::DecShutter()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::DecShutter() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_ShutterPresent)
	{
		ost << "CCameraFirewireCMU::DecShutter() Shutter not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_ShutterValue;
	Val--;
	if (Val < m_ShutterMin){
		Val = m_ShutterMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetShutter(Val);
	m_ShutterValue = Val;
	if(m_phCamera->m_controlShutter.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::ShutterDouble()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::ShutterDouble() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available
	if (!m_ShutterPresent)
	{
		ost << "CCameraFirewireCMU::ShutterDouble() Shutter not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	} 
	
	int Val = m_ShutterValue*2;
	if (Val > m_ShutterMax){
		Val = m_ShutterMax;
	}
	//Call control class update shortcut			
	m_phCamera->SetShutter(Val);
	m_ShutterValue = Val;
	if(m_phCamera->m_controlShutter.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::ShutterHalf()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::ShutterHalf() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_ShutterPresent)
	{
		ost << "CCameraFirewireCMU::ShutterHalf() Shutter not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_ShutterValue/2;
	if (Val < m_ShutterMin){
		Val = m_ShutterMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetShutter(Val);
	m_ShutterValue = Val;
	if(m_phCamera->m_controlShutter.m_value1==Val)
		return Val;
	return -1;
}

bool CCameraFirewireCMU::ReadShutter()
{
	m_phCamera->m_controlShutter.Inquire();
	m_ShutterPresent = m_phCamera->m_controlShutter.m_present;
	if (m_ShutterPresent)
	{
		m_ShutterAuto = m_phCamera->m_controlShutter.m_statusAutoManual;
		m_ShutterValue = m_phCamera->m_controlShutter.m_value1;
		m_ShutterMin = m_phCamera->m_controlShutter.m_min;
		m_ShutterMax = m_phCamera->m_controlShutter.m_max;
		return true;
	}
	m_ShutterValue = -1;
	m_ShutterMin = -1;
	m_ShutterMax = -1;
	return false;
}

bool CCameraFirewireCMU::GetShutterAuto() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetShutterAuto() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_ShutterAuto;
	
}

bool CCameraFirewireCMU::SetShutterAuto(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetShutterAuto() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_ShutterPresent)
	{
		ost << "CCameraFirewireCMU::SetShutterAuto() Shutter not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlShutter.SetAutoMode(Value);
	if (success==CAM_SUCCESS){
		m_ShutterAuto = Value;
		return true;
	}
	return false;
}

bool CCameraFirewireCMU::GetShutterOn() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetShutterOn() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_ShutterOn;
}

bool CCameraFirewireCMU::SetShutterOn(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetShutterOn() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_ShutterPresent)
	{
		ost << "CCameraFirewireCMU::SetShutterOn() Shutter not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlShutter.TurnOn(Value);
	if (success==CAM_SUCCESS){
		m_ShutterOn = Value;
		return true;
	}
	return false;
}

/* *************************** *
* ----- External Trigger ---- *
* *************************** */


bool CCameraFirewireCMU::ExternalTriggerAvailable() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::ExternalTriggerAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_phCamera->m_controlTrigger.m_present;	
}

bool CCameraFirewireCMU::SetExternalTriggerOnOff(bool onOff) const
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetExternalTriggerOnOff() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(!m_phCamera->m_controlTrigger.m_onoff)
	{
		ost << "CCameraFirewireCMU::SetExternalTriggerOnOff() External trigger can't be switched on/off from software." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(m_phCamera->m_controlTrigger.TurnOn(onOff) == CAM_SUCCESS)
		return true;
	else
	{
		ost << "CCameraFirewireCMU::SetExternalTriggerOnOff() Error setting external trigger on/off." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
}

bool CCameraFirewireCMU::GetExternalTriggerOnOffStatus() const
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::ExternalTriggerOnOff() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	C1394CameraControlTrigger &control = m_phCamera->m_controlTrigger;
	if(control.Status()!=CAM_SUCCESS)
	{
		ost << "CCameraFirewireCMU::ExternalTriggerOnOff() Error collecting information." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return control.m_statusOnOff;
}

bool CCameraFirewireCMU::SetExternalTriggerPolarity(const bool Polarity) const
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetExternalTriggerPolarity() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(!m_phCamera->m_controlTrigger.m_polarity)
	{
		ost << "CCameraFirewireCMU::SetExternalTriggerPolarity() External trigger polarity can't be inverted." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(m_phCamera->m_controlTrigger.SetPolarity(Polarity) == CAM_SUCCESS)
		return true;
	else
	{
		ost << "CCameraFirewireCMU::SetExternalTriggerPolarity() Error setting external trigger polarity." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
}


bool CCameraFirewireCMU::GetExternalTriggerPolarity() const
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::GetExternalTriggerPolarity() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	C1394CameraControlTrigger &control = m_phCamera->m_controlTrigger;
	if(control.Status() !=CAM_SUCCESS)
	{
		ost << "CCameraFirewireCMU::GetExternalTriggerPolarity() Error collecting information." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return control.m_statusPolarity;
}

bool CCameraFirewireCMU::SetExternalTriggerMode(unsigned int Mode, int N)
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetExternalTriggerMode() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	C1394CameraControlTrigger &control = m_phCamera->m_controlTrigger;
	if(!control.m_triggerMode[Mode])
	{
		ost << "CCameraFirewireCMU::SetExternalTriggerMode() Trigger mode not available." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(Mode == 2 && N < 2)
	{
		ost << "CCameraFirewireCMU::SetExternalTriggerMode() For mode 2, N must be larger than or equal to two." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(Mode == 3 && N < 1)
	{
		ost << "CCameraFirewireCMU::SetExternalTriggerMode() For mode 3, N must be larger than or equal to one." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(control.SetMode(Mode, N) == CAM_SUCCESS)
		return true;
	else
	{
		ost << "CCameraFirewireCMU::SetExternalTriggerMode() Error setting external trigger mode." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
}

unsigned int CCameraFirewireCMU::GetExternalTriggerMode()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::GetExternalTriggerMode() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	C1394CameraControlTrigger &control = m_phCamera->m_controlTrigger;
	if(control.Status() != CAM_SUCCESS)
	{
		ost << "CCameraFirewireCMU::GetExternalTriggerMode() Error collecting information." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return control.m_statusMode;
}

bool CCameraFirewireCMU::GetExternalTriggerModesAvailable(vector<bool>& Modes) const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetExternalTriggerModesAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(!m_phCamera->m_controlTrigger.m_present)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetExternalTriggerModesAvailable() External Trigger not supported." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	Modes.clear();
	for(int i=0; i<4; i++)
	{
		Modes.push_back(m_phCamera->m_controlTrigger.m_triggerMode[i]);
	}
	return true;
}

bool CCameraFirewireCMU::ExternalTriggerModeAvailable(unsigned int Mode) const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::ExternalTriggerModeAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if(!m_phCamera->m_controlTrigger.m_present)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::ExternalTriggerModeAvailable() External Trigger not supported." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_phCamera->m_controlTrigger.m_triggerMode[Mode];
}

/* *************************** *
* ------ WhiteBalance ------- *
* *************************** */


/*Check if camera support WhiteBalance*/
bool CCameraFirewireCMU::WhiteBalanceAvailable() const 
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::WhiteBalanceAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_WhiteBalancePresent;
}

pair<double, double> CCameraFirewireCMU::GetWhiteBalance() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetWhiteBalance() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return pair<double, double>(-1,-1);
	}
	if (!m_WhiteBalancePresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetWhiteBalance() WhiteBalance not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return pair<double, double>(-1,-1);
	}
	return pair<double, double>(m_WhiteBalanceUB, m_WhiteBalanceVR);
}


double CCameraFirewireCMU::GetWhiteBalanceMin() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetWhiteBalanceMin() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_WhiteBalancePresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetWhiteBalance() WhiteBalance not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_WhiteBalanceMin;
}


double CCameraFirewireCMU::GetWhiteBalanceMax() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetWhiteBalanceMax() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_WhiteBalancePresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetWhiteBalance() WhiteBalance not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_WhiteBalanceMax;
}


pair<double, double> CCameraFirewireCMU::SetWhiteBalance(double UB, double VR)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetWhiteBalance() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return pair<double, double>(-1,-1);
	}
	if (!m_WhiteBalancePresent)
	{
		ost << "CCameraFirewireCMU::SetWhiteBalance() WhiteBalance not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return pair<double, double>(-1,-1);
	}
	// Check if feature is available 
	if (UB > m_WhiteBalanceMax){
		UB = m_WhiteBalanceMax;
	}
	else if (UB < m_WhiteBalanceMin){
		UB = m_WhiteBalanceMin;
	}
	if (VR > m_WhiteBalanceMax){
		VR = m_WhiteBalanceMax;
	}
	else if (VR < m_WhiteBalanceMin){
		VR = m_WhiteBalanceMin;
	}
	//Call control class update shortcut
	unsigned int UB2=(int)(UB);
	unsigned int VR2=(int)(VR);
	m_phCamera->SetWhiteBalance(UB2, VR2);
	m_WhiteBalanceUB = UB2;
	m_WhiteBalanceVR = VR2;
	if(m_phCamera->m_controlWhiteBalance.m_value2==UB2 && m_phCamera->m_controlWhiteBalance.m_value1==VR2)
		return pair<double, double>(UB,VR);
	return pair<double, double>(-1,-1);
}

bool CCameraFirewireCMU::ReadWhiteBalance()
{
	m_phCamera->m_controlWhiteBalance.Inquire();
	m_WhiteBalancePresent = m_phCamera->m_controlWhiteBalance.m_present;
	if (m_phCamera->m_controlWhiteBalance.m_present)
	{
		m_WhiteBalanceAuto = m_phCamera->m_controlWhiteBalance.m_statusAutoManual;
		m_WhiteBalanceUB = m_phCamera->m_controlWhiteBalance.m_value1;
		m_WhiteBalanceVR = m_phCamera->m_controlWhiteBalance.m_value2;
		m_WhiteBalanceMin = m_phCamera->m_controlWhiteBalance.m_min;
		m_WhiteBalanceMax = m_phCamera->m_controlWhiteBalance.m_max;
		return true;
	}
	m_WhiteBalanceUB = -1;
	m_WhiteBalanceVR = -1;
	m_WhiteBalanceMin = -1;
	m_WhiteBalanceMax = -1;
	return false;
}

bool CCameraFirewireCMU::GetWhiteBalanceAuto() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetWhiteBalanceAuto() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_WhiteBalanceAuto;
	
}

bool CCameraFirewireCMU::SetWhiteBalanceAuto(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetWhiteBalanceAuto() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_WhiteBalancePresent)
	{
		ost << "CCameraFirewireCMU::SetWhiteBalanceAuto() WhiteBalance not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlWhiteBalance.SetAutoMode(Value);
	if (success==CAM_SUCCESS){
		m_WhiteBalanceAuto = Value;
		return true;
	}
	return false;
}

bool CCameraFirewireCMU::GetWhiteBalanceOn() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetWhiteBalanceOn() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_WhiteBalanceOn;
}

bool CCameraFirewireCMU::SetWhiteBalanceOn(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetWhiteBalanceOn() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_WhiteBalancePresent)
	{
		ost << "CCameraFirewireCMU::SetWhiteBalanceOn() WhiteBalance not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlWhiteBalance.TurnOn(Value);
	if (success==CAM_SUCCESS){
		m_WhiteBalanceOn = Value;
		return true;
	}
	return false;
}

/* *************************** *
* ---------- Zoom ----------- *
* *************************** */


/*Check if camera support Zoom*/
bool CCameraFirewireCMU::ZoomAvailable() const 
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::ZoomAvailable() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_ZoomPresent;		
}


double CCameraFirewireCMU::GetZoom() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetZoom() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_ZoomPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetZoom() Zoom not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_ZoomValue;
}


double CCameraFirewireCMU::GetZoomMin() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetZoomMin() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_ZoomPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetZoom() Zoom not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_ZoomMin;
}


double CCameraFirewireCMU::GetZoomMax() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetZoomMax() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_ZoomPresent)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetZoom() Zoom not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	return m_ZoomMax;
}


double CCameraFirewireCMU::SetZoom(double Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetZoom() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_ZoomPresent)
	{
		ost << "CCameraFirewireCMU::SetZoom() Zoom not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (Value > m_ZoomMax){
		Value = m_ZoomMax;
	}
	else if (Value < m_ZoomMin){
		Value = m_ZoomMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetZoom(Value);
	m_ZoomValue = Value;
	if(m_phCamera->m_controlZoom.m_value1==Value)
		return Value;
	return -1;
}


double CCameraFirewireCMU::IncZoom()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::IncZoom() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	if (!m_ZoomPresent)
	{
		ost << "CCameraFirewireCMU::IncZoom() Zoom not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	int Val = m_ZoomValue;
	Val++;
	if (Val> m_ZoomMax){
		Val = m_ZoomMax;
	}
	//Call control class update shortcut				
	m_phCamera->SetZoom(Val);
	m_ZoomValue = Val;
	if(m_phCamera->m_controlZoom.m_value1==Val)
		return Val;
	return -1;
}

double CCameraFirewireCMU::DecZoom()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::DecZoom() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_ZoomPresent)
	{
		ost << "CCameraFirewireCMU::DecZoom() Zoom not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_ZoomValue;
	Val--;
	if (Val < m_ZoomMin){
		Val = m_ZoomMin;
	}
	//Call control class update shortcut			
	m_phCamera->SetZoom(Val);
	m_ZoomValue = Val;
	if(m_phCamera->m_controlZoom.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::ZoomDouble()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::ZoomDouble() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available
	if (!m_ZoomPresent)
	{
		ost << "CCameraFirewireCMU::ZoomDouble() Zoom not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	} 
	
	int Val = m_ZoomValue*2;
	if (Val > m_ZoomMax){
		Val = m_ZoomMax;
	}
	//Call control class update shortcut			
	m_phCamera->SetZoom(Val);
	m_ZoomValue = Val;
	if(m_phCamera->m_controlZoom.m_value1==Val)
		return Val;
	return -1;
}


double CCameraFirewireCMU::ZoomHalf()
{
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::ZoomHalf() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	// Check if feature is available 
	if (!m_ZoomPresent)
	{
		ost << "CCameraFirewireCMU::ZoomHalf() Zoom not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return -1;
	}
	
	int Val = m_ZoomValue/2;
	if (Val < m_ZoomMin){
		Val = m_ZoomMin;
	}
	//Call control class update shortcut						
	m_phCamera->SetZoom(Val);
	m_ZoomValue = Val;
	if(m_phCamera->m_controlZoom.m_value1==Val)
		return Val;
	return -1;
}

bool CCameraFirewireCMU::ReadZoom()
{
	m_phCamera->m_controlZoom.Inquire();
	m_ZoomPresent = m_phCamera->m_controlZoom.m_present;
	if (m_ZoomPresent)
	{
		m_ZoomValue = m_phCamera->m_controlZoom.m_value1;
		m_ZoomMin = m_phCamera->m_controlZoom.m_min;
		m_ZoomMax = m_phCamera->m_controlZoom.m_max;
		return true;
	}
	m_ZoomValue = -1;
	m_ZoomMin = -1;
	m_ZoomMax = -1;
	return false;
}

bool CCameraFirewireCMU::GetZoomOn() const
{
	if (!m_Initialized)
	{
		strstream ost;
		ost << "CCameraFirewireCMU::GetZoomOn() Must call Initialize() first." << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	return m_ZoomOn;
}

bool CCameraFirewireCMU::SetZoomOn(bool Value)
{	
	strstream ost;
	if (!m_Initialized)
	{
		ost << "CCameraFirewireCMU::SetZoomOn() Must call Initialize() first." 
			<< "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}
	if (!m_ZoomPresent)
	{
		ost << "CCameraFirewireCMU::SetZoomOn() Zoom not available" << "\n";
		//CError::ShowMessage(IPL_ERROR,ost.str().c_str());
		return false;
	}			
	//Call control class update shortcut
	int success = m_phCamera->m_controlZoom.TurnOn(Value);
	if (success==CAM_SUCCESS){
		m_ZoomOn = Value;
		return true;
	}
	return false;
}
